Class: Aws::Redshift::Types::ClusterCredentials
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::ClusterCredentials
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Temporary credentials with authorization to log on to an Amazon Redshift database.
Constant Summary collapse
- SENSITIVE =
[:db_password]
Instance Attribute Summary collapse
-
#db_password ⇒ String
A temporary password that authorizes the user name returned by
DbUserto log on to the databaseDbName. -
#db_user ⇒ String
A database user name that is authorized to log on to the database
DbNameusing the passwordDbPassword. -
#expiration ⇒ Time
The date and time the password in
DbPasswordexpires.
Instance Attribute Details
#db_password ⇒ String
A temporary password that authorizes the user name returned by
DbUser to log on to the database DbName.
1096 1097 1098 1099 1100 1101 1102 |
# File 'lib/aws-sdk-redshift/types.rb', line 1096 class ClusterCredentials < Struct.new( :db_user, :db_password, :expiration) SENSITIVE = [:db_password] include Aws::Structure end |
#db_user ⇒ String
A database user name that is authorized to log on to the database
DbName using the password DbPassword. If the specified DbUser
exists in the database, the new user name has the same database
permissions as the the user named in DbUser. By default, the user is
added to PUBLIC. If the DbGroups parameter is specifed, DbUser
is added to the listed groups for any sessions created using these
credentials.
1096 1097 1098 1099 1100 1101 1102 |
# File 'lib/aws-sdk-redshift/types.rb', line 1096 class ClusterCredentials < Struct.new( :db_user, :db_password, :expiration) SENSITIVE = [:db_password] include Aws::Structure end |
#expiration ⇒ Time
The date and time the password in DbPassword expires.
1096 1097 1098 1099 1100 1101 1102 |
# File 'lib/aws-sdk-redshift/types.rb', line 1096 class ClusterCredentials < Struct.new( :db_user, :db_password, :expiration) SENSITIVE = [:db_password] include Aws::Structure end |