Class: Aws::Redshift::Types::ClusterSecurityGroupMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_security_groupsArray<Types::ClusterSecurityGroup>

A list of ClusterSecurityGroup instances.

Returns:



1551
1552
1553
1554
1555
1556
# File 'lib/aws-sdk-redshift/types.rb', line 1551

class ClusterSecurityGroupMessage < Struct.new(
  :marker,
  :cluster_security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


1551
1552
1553
1554
1555
1556
# File 'lib/aws-sdk-redshift/types.rb', line 1551

class ClusterSecurityGroupMessage < Struct.new(
  :marker,
  :cluster_security_groups)
  SENSITIVE = []
  include Aws::Structure
end