Class: Aws::Redshift::Types::CreateEndpointAccessMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

The cluster identifier of the cluster to access.



2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-redshift/types.rb', line 2773

class CreateEndpointAccessMessage < Struct.new(
  :cluster_identifier,
  :resource_owner,
  :endpoint_name,
  :subnet_group_name,
  :vpc_security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_nameString

The Redshift-managed VPC endpoint name.

An endpoint name must contain 1-30 characters. Valid characters are A-Z, a-z, 0-9, and hyphen(-). The first character must be a letter. The name can't contain two consecutive hyphens or end with a hyphen.



2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-redshift/types.rb', line 2773

class CreateEndpointAccessMessage < Struct.new(
  :cluster_identifier,
  :resource_owner,
  :endpoint_name,
  :subnet_group_name,
  :vpc_security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#resource_ownerString

The Amazon Web Services account ID of the owner of the cluster. This is only required if the cluster is in another Amazon Web Services account.



2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-redshift/types.rb', line 2773

class CreateEndpointAccessMessage < Struct.new(
  :cluster_identifier,
  :resource_owner,
  :endpoint_name,
  :subnet_group_name,
  :vpc_security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_group_nameString

The subnet group from which Amazon Redshift chooses the subnet to deploy the endpoint.



2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-redshift/types.rb', line 2773

class CreateEndpointAccessMessage < Struct.new(
  :cluster_identifier,
  :resource_owner,
  :endpoint_name,
  :subnet_group_name,
  :vpc_security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_security_group_idsArray<String>

The security group that defines the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.



2773
2774
2775
2776
2777
2778
2779
2780
2781
# File 'lib/aws-sdk-redshift/types.rb', line 2773

class CreateEndpointAccessMessage < Struct.new(
  :cluster_identifier,
  :resource_owner,
  :endpoint_name,
  :subnet_group_name,
  :vpc_security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end