Class: Aws::Redshift::Types::CreateHsmClientCertificateMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::CreateHsmClientCertificateMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hsm_client_certificate_identifier ⇒ String
The identifier to be assigned to the new HSM client certificate that the cluster will use to connect to the HSM to use the database encryption keys.
-
#tags ⇒ Array<Types::Tag>
A list of tag instances.
Instance Attribute Details
#hsm_client_certificate_identifier ⇒ String
The identifier to be assigned to the new HSM client certificate that the cluster will use to connect to the HSM to use the database encryption keys.
2890 2891 2892 2893 2894 2895 |
# File 'lib/aws-sdk-redshift/types.rb', line 2890 class CreateHsmClientCertificateMessage < Struct.new( :hsm_client_certificate_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tag instances.
2890 2891 2892 2893 2894 2895 |
# File 'lib/aws-sdk-redshift/types.rb', line 2890 class CreateHsmClientCertificateMessage < Struct.new( :hsm_client_certificate_identifier, :tags) SENSITIVE = [] include Aws::Structure end |