Class: Aws::Redshift::Types::CreateIntegrationMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_encryption_contextHash<String,String>

An optional set of non-secret key–value pairs that contains additional contextual information about the data. For more information, see Encryption context in the Amazon Web Services Key Management Service Developer Guide.

You can only include this parameter if you specify the KMSKeyId parameter.

Returns:

  • (Hash<String,String>)


3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
# File 'lib/aws-sdk-redshift/types.rb', line 3016

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :tag_list,
  :additional_encryption_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the integration.

Returns:

  • (String)


3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
# File 'lib/aws-sdk-redshift/types.rb', line 3016

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :tag_list,
  :additional_encryption_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#integration_nameString

The name of the integration.

Returns:

  • (String)


3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
# File 'lib/aws-sdk-redshift/types.rb', line 3016

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :tag_list,
  :additional_encryption_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

An Key Management Service (KMS) key identifier for the key to use to encrypt the integration. If you don't specify an encryption key, the default Amazon Web Services owned key is used.

Returns:

  • (String)


3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
# File 'lib/aws-sdk-redshift/types.rb', line 3016

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :tag_list,
  :additional_encryption_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The Amazon Resource Name (ARN) of the database to use as the source for replication.

Returns:

  • (String)


3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
# File 'lib/aws-sdk-redshift/types.rb', line 3016

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :tag_list,
  :additional_encryption_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#tag_listArray<Types::Tag>

A list of tags.

Returns:



3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
# File 'lib/aws-sdk-redshift/types.rb', line 3016

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :tag_list,
  :additional_encryption_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The Amazon Resource Name (ARN) of the Amazon Redshift data warehouse to use as the target for replication.

Returns:

  • (String)


3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
# File 'lib/aws-sdk-redshift/types.rb', line 3016

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :tag_list,
  :additional_encryption_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end