Class: Aws::Redshift::Types::CreateQev2IdcApplicationMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idc_display_nameString

The display name for the Amazon Redshift Query Editor (QEV2) IAM Identity Center application. It appears in the console.

Returns:

  • (String)


3045
3046
3047
3048
3049
3050
3051
3052
# File 'lib/aws-sdk-redshift/types.rb', line 3045

class CreateQev2IdcApplicationMessage < Struct.new(
  :idc_instance_arn,
  :qev_2_idc_application_name,
  :idc_display_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idc_instance_arnString

The Amazon Resource Name (ARN) of the IAM Identity Center instance used to create the Amazon Redshift Query Editor (QEV2) managed application.

Returns:

  • (String)


3045
3046
3047
3048
3049
3050
3051
3052
# File 'lib/aws-sdk-redshift/types.rb', line 3045

class CreateQev2IdcApplicationMessage < Struct.new(
  :idc_instance_arn,
  :qev_2_idc_application_name,
  :idc_display_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#qev_2_idc_application_nameString

The name of the Amazon Redshift Query Editor (QEV2) application in IAM Identity Center.

Returns:

  • (String)


3045
3046
3047
3048
3049
3050
3051
3052
# File 'lib/aws-sdk-redshift/types.rb', line 3045

class CreateQev2IdcApplicationMessage < Struct.new(
  :idc_instance_arn,
  :qev_2_idc_application_name,
  :idc_display_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags to associate with the application. Tags are key-value pairs that you can use to organize and identify your resources.

Returns:



3045
3046
3047
3048
3049
3050
3051
3052
# File 'lib/aws-sdk-redshift/types.rb', line 3045

class CreateQev2IdcApplicationMessage < Struct.new(
  :idc_instance_arn,
  :qev_2_idc_application_name,
  :idc_display_name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end