Class: Aws::Redshift::Types::CreateRedshiftIdcApplicationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::CreateRedshiftIdcApplicationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_type ⇒ String
The type of application being created.
-
#authorized_token_issuer_list ⇒ Array<Types::AuthorizedTokenIssuer>
The token issuer list for the Amazon Redshift IAM Identity Center application instance.
-
#iam_role_arn ⇒ String
The IAM role ARN for the Amazon Redshift IAM Identity Center application instance.
-
#idc_display_name ⇒ String
The display name for the Amazon Redshift IAM Identity Center application instance.
-
#idc_instance_arn ⇒ String
The Amazon resource name (ARN) of the IAM Identity Center instance where Amazon Redshift creates a new managed application.
-
#identity_namespace ⇒ String
The namespace for the Amazon Redshift IAM Identity Center application instance.
-
#redshift_idc_application_name ⇒ String
The name of the Redshift application in IAM Identity Center.
-
#service_integrations ⇒ Array<Types::ServiceIntegrationsUnion>
A collection of service integrations for the Redshift IAM Identity Center application.
-
#sso_tag_keys ⇒ Array<String>
A list of tags keys that Redshift Identity Center applications copy to IAM Identity Center.
-
#tags ⇒ Array<Types::Tag>
A list of tags.
Instance Attribute Details
#application_type ⇒ String
The type of application being created. Valid values are None or
Lakehouse. Use Lakehouse to enable Amazon Redshift federated
permissions on cluster.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/aws-sdk-redshift/types.rb', line 3122 class CreateRedshiftIdcApplicationMessage < Struct.new( :idc_instance_arn, :redshift_idc_application_name, :identity_namespace, :idc_display_name, :iam_role_arn, :authorized_token_issuer_list, :service_integrations, :application_type, :tags, :sso_tag_keys) SENSITIVE = [] include Aws::Structure end |
#authorized_token_issuer_list ⇒ Array<Types::AuthorizedTokenIssuer>
The token issuer list for the Amazon Redshift IAM Identity Center application instance.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/aws-sdk-redshift/types.rb', line 3122 class CreateRedshiftIdcApplicationMessage < Struct.new( :idc_instance_arn, :redshift_idc_application_name, :identity_namespace, :idc_display_name, :iam_role_arn, :authorized_token_issuer_list, :service_integrations, :application_type, :tags, :sso_tag_keys) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The IAM role ARN for the Amazon Redshift IAM Identity Center application instance. It has the required permissions to be assumed and invoke the IDC Identity Center API.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/aws-sdk-redshift/types.rb', line 3122 class CreateRedshiftIdcApplicationMessage < Struct.new( :idc_instance_arn, :redshift_idc_application_name, :identity_namespace, :idc_display_name, :iam_role_arn, :authorized_token_issuer_list, :service_integrations, :application_type, :tags, :sso_tag_keys) SENSITIVE = [] include Aws::Structure end |
#idc_display_name ⇒ String
The display name for the Amazon Redshift IAM Identity Center application instance. It appears in the console.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/aws-sdk-redshift/types.rb', line 3122 class CreateRedshiftIdcApplicationMessage < Struct.new( :idc_instance_arn, :redshift_idc_application_name, :identity_namespace, :idc_display_name, :iam_role_arn, :authorized_token_issuer_list, :service_integrations, :application_type, :tags, :sso_tag_keys) SENSITIVE = [] include Aws::Structure end |
#idc_instance_arn ⇒ String
The Amazon resource name (ARN) of the IAM Identity Center instance where Amazon Redshift creates a new managed application.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/aws-sdk-redshift/types.rb', line 3122 class CreateRedshiftIdcApplicationMessage < Struct.new( :idc_instance_arn, :redshift_idc_application_name, :identity_namespace, :idc_display_name, :iam_role_arn, :authorized_token_issuer_list, :service_integrations, :application_type, :tags, :sso_tag_keys) SENSITIVE = [] include Aws::Structure end |
#identity_namespace ⇒ String
The namespace for the Amazon Redshift IAM Identity Center application instance. It determines which managed application verifies the connection token.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/aws-sdk-redshift/types.rb', line 3122 class CreateRedshiftIdcApplicationMessage < Struct.new( :idc_instance_arn, :redshift_idc_application_name, :identity_namespace, :idc_display_name, :iam_role_arn, :authorized_token_issuer_list, :service_integrations, :application_type, :tags, :sso_tag_keys) SENSITIVE = [] include Aws::Structure end |
#redshift_idc_application_name ⇒ String
The name of the Redshift application in IAM Identity Center.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/aws-sdk-redshift/types.rb', line 3122 class CreateRedshiftIdcApplicationMessage < Struct.new( :idc_instance_arn, :redshift_idc_application_name, :identity_namespace, :idc_display_name, :iam_role_arn, :authorized_token_issuer_list, :service_integrations, :application_type, :tags, :sso_tag_keys) SENSITIVE = [] include Aws::Structure end |
#service_integrations ⇒ Array<Types::ServiceIntegrationsUnion>
A collection of service integrations for the Redshift IAM Identity Center application.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/aws-sdk-redshift/types.rb', line 3122 class CreateRedshiftIdcApplicationMessage < Struct.new( :idc_instance_arn, :redshift_idc_application_name, :identity_namespace, :idc_display_name, :iam_role_arn, :authorized_token_issuer_list, :service_integrations, :application_type, :tags, :sso_tag_keys) SENSITIVE = [] include Aws::Structure end |
#sso_tag_keys ⇒ Array<String>
A list of tags keys that Redshift Identity Center applications copy to IAM Identity Center. For each input key, the tag corresponding to the key-value pair is propagated.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/aws-sdk-redshift/types.rb', line 3122 class CreateRedshiftIdcApplicationMessage < Struct.new( :idc_instance_arn, :redshift_idc_application_name, :identity_namespace, :idc_display_name, :iam_role_arn, :authorized_token_issuer_list, :service_integrations, :application_type, :tags, :sso_tag_keys) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/aws-sdk-redshift/types.rb', line 3122 class CreateRedshiftIdcApplicationMessage < Struct.new( :idc_instance_arn, :redshift_idc_application_name, :identity_namespace, :idc_display_name, :iam_role_arn, :authorized_token_issuer_list, :service_integrations, :application_type, :tags, :sso_tag_keys) SENSITIVE = [] include Aws::Structure end |