Class: Aws::Redshift::Types::CreateScheduledActionMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enableBoolean

If true, the schedule is enabled. If false, the scheduled action does not trigger. For more information about state of the scheduled action, see ScheduledAction.

Returns:

  • (Boolean)


3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-redshift/types.rb', line 3201

class CreateScheduledActionMessage < Struct.new(
  :scheduled_action_name,
  :target_action,
  :schedule,
  :iam_role,
  :scheduled_action_description,
  :start_time,
  :end_time,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end time in UTC of the scheduled action. After this time, the scheduled action does not trigger. For more information about this parameter, see ScheduledAction.

Returns:

  • (Time)


3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-redshift/types.rb', line 3201

class CreateScheduledActionMessage < Struct.new(
  :scheduled_action_name,
  :target_action,
  :schedule,
  :iam_role,
  :scheduled_action_description,
  :start_time,
  :end_time,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end

#iam_roleString

The IAM role to assume to run the target action. For more information about this parameter, see ScheduledAction.

Returns:

  • (String)


3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-redshift/types.rb', line 3201

class CreateScheduledActionMessage < Struct.new(
  :scheduled_action_name,
  :target_action,
  :schedule,
  :iam_role,
  :scheduled_action_description,
  :start_time,
  :end_time,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleString

The schedule in at( ) or cron( ) format. For more information about this parameter, see ScheduledAction.

Returns:

  • (String)


3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-redshift/types.rb', line 3201

class CreateScheduledActionMessage < Struct.new(
  :scheduled_action_name,
  :target_action,
  :schedule,
  :iam_role,
  :scheduled_action_description,
  :start_time,
  :end_time,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_action_descriptionString

The description of the scheduled action.

Returns:

  • (String)


3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-redshift/types.rb', line 3201

class CreateScheduledActionMessage < Struct.new(
  :scheduled_action_name,
  :target_action,
  :schedule,
  :iam_role,
  :scheduled_action_description,
  :start_time,
  :end_time,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_action_nameString

The name of the scheduled action. The name must be unique within an account. For more information about this parameter, see ScheduledAction.

Returns:

  • (String)


3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-redshift/types.rb', line 3201

class CreateScheduledActionMessage < Struct.new(
  :scheduled_action_name,
  :target_action,
  :schedule,
  :iam_role,
  :scheduled_action_description,
  :start_time,
  :end_time,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start time in UTC of the scheduled action. Before this time, the scheduled action does not trigger. For more information about this parameter, see ScheduledAction.

Returns:

  • (Time)


3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-redshift/types.rb', line 3201

class CreateScheduledActionMessage < Struct.new(
  :scheduled_action_name,
  :target_action,
  :schedule,
  :iam_role,
  :scheduled_action_description,
  :start_time,
  :end_time,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end

#target_actionTypes::ScheduledActionType

A JSON format string of the Amazon Redshift API operation with input parameters. For more information about this parameter, see ScheduledAction.



3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
# File 'lib/aws-sdk-redshift/types.rb', line 3201

class CreateScheduledActionMessage < Struct.new(
  :scheduled_action_name,
  :target_action,
  :schedule,
  :iam_role,
  :scheduled_action_description,
  :start_time,
  :end_time,
  :enable)
  SENSITIVE = []
  include Aws::Structure
end