Class: Aws::Redshift::Types::CreateSnapshotCopyGrantResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::CreateSnapshotCopyGrantResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#snapshot_copy_grant ⇒ Types::SnapshotCopyGrant
The snapshot copy grant that grants Amazon Redshift permission to encrypt copied snapshots with the specified encrypted symmetric key from Amazon Web Services KMS in the destination region.
Instance Attribute Details
#snapshot_copy_grant ⇒ Types::SnapshotCopyGrant
The snapshot copy grant that grants Amazon Redshift permission to encrypt copied snapshots with the specified encrypted symmetric key from Amazon Web Services KMS in the destination region.
For more information about managing snapshot copy grants, go to Amazon Redshift Database Encryption in the Amazon Redshift Cluster Management Guide.
3270 3271 3272 3273 3274 |
# File 'lib/aws-sdk-redshift/types.rb', line 3270 class CreateSnapshotCopyGrantResult < Struct.new( :snapshot_copy_grant) SENSITIVE = [] include Aws::Structure end |