Class: Aws::Redshift::Types::CreateUsageLimitMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amountInteger

The limit amount. If time-based, this amount is in minutes. If data-based, this amount is in terabytes (TB). The value must be a positive number.



3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
# File 'lib/aws-sdk-redshift/types.rb', line 3383

class CreateUsageLimitMessage < Struct.new(
  :cluster_identifier,
  :feature_type,
  :limit_type,
  :amount,
  :period,
  :breach_action,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#breach_actionString

The action that Amazon Redshift takes when the limit is reached. The default is log. For more information about this parameter, see UsageLimit.



3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
# File 'lib/aws-sdk-redshift/types.rb', line 3383

class CreateUsageLimitMessage < Struct.new(
  :cluster_identifier,
  :feature_type,
  :limit_type,
  :amount,
  :period,
  :breach_action,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_identifierString

The identifier of the cluster that you want to limit usage.



3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
# File 'lib/aws-sdk-redshift/types.rb', line 3383

class CreateUsageLimitMessage < Struct.new(
  :cluster_identifier,
  :feature_type,
  :limit_type,
  :amount,
  :period,
  :breach_action,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#feature_typeString

The Amazon Redshift feature that you want to limit.



3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
# File 'lib/aws-sdk-redshift/types.rb', line 3383

class CreateUsageLimitMessage < Struct.new(
  :cluster_identifier,
  :feature_type,
  :limit_type,
  :amount,
  :period,
  :breach_action,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#limit_typeString

The type of limit. Depending on the feature type, this can be based on a time duration or data size. If FeatureType is spectrum, then LimitType must be data-scanned. If FeatureType is concurrency-scaling, then LimitType must be time. If FeatureType is cross-region-datasharing, then LimitType must be data-scanned. If FeatureType is extra-compute-for-automatic-optimization, then LimitType must be time.



3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
# File 'lib/aws-sdk-redshift/types.rb', line 3383

class CreateUsageLimitMessage < Struct.new(
  :cluster_identifier,
  :feature_type,
  :limit_type,
  :amount,
  :period,
  :breach_action,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#periodString

The time period that the amount applies to. A weekly period begins on Sunday. The default is monthly.



3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
# File 'lib/aws-sdk-redshift/types.rb', line 3383

class CreateUsageLimitMessage < Struct.new(
  :cluster_identifier,
  :feature_type,
  :limit_type,
  :amount,
  :period,
  :breach_action,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tag instances.



3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
# File 'lib/aws-sdk-redshift/types.rb', line 3383

class CreateUsageLimitMessage < Struct.new(
  :cluster_identifier,
  :feature_type,
  :limit_type,
  :amount,
  :period,
  :breach_action,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end