Class: Aws::Redshift::Types::DeleteTagsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DeleteTagsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Contains the output from the DeleteTags action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_name ⇒ String
The Amazon Resource Name (ARN) from which you want to remove the tag or tags.
-
#tag_keys ⇒ Array<String>
The tag key that you want to delete.
Instance Attribute Details
#resource_name ⇒ String
The Amazon Resource Name (ARN) from which you want to remove the tag or tags. For example, arn:aws:redshift:us-east-2:123456789:cluster:t1.
3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-redshift/types.rb', line 3933 class DeleteTagsMessage < Struct.new( :resource_name, :tag_keys) SENSITIVE = [] include Aws::Structure end |
#tag_keys ⇒ Array<String>
The tag key that you want to delete.
3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-redshift/types.rb', line 3933 class DeleteTagsMessage < Struct.new( :resource_name, :tag_keys) SENSITIVE = [] include Aws::Structure end |