Class: Aws::Redshift::Types::DescribeClusterDbRevisionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

A unique identifier for a cluster whose ClusterDbRevisions you are requesting. This parameter is case sensitive. All clusters defined for an account are returned by default.

Returns:

  • (String)


4141
4142
4143
4144
4145
4146
4147
# File 'lib/aws-sdk-redshift/types.rb', line 4141

class DescribeClusterDbRevisionsMessage < Struct.new(
  :cluster_identifier,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional parameter that specifies the starting point for returning a set of response records. When the results of a DescribeClusterDbRevisions request exceed the value specified in MaxRecords, Amazon Redshift returns a value in the marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the marker parameter and retrying the request.

Constraints: You can specify either the ClusterIdentifier parameter, or the marker parameter, but not both.

Returns:

  • (String)


4141
4142
4143
4144
4145
4146
4147
# File 'lib/aws-sdk-redshift/types.rb', line 4141

class DescribeClusterDbRevisionsMessage < Struct.new(
  :cluster_identifier,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in the marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the marker parameter and retrying the request.

Default: 100

Constraints: minimum 20, maximum 100.

Returns:

  • (Integer)


4141
4142
4143
4144
4145
4146
4147
# File 'lib/aws-sdk-redshift/types.rb', line 4141

class DescribeClusterDbRevisionsMessage < Struct.new(
  :cluster_identifier,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end