Class: Aws::Redshift::Types::DescribeDataSharesForConsumerMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeDataSharesForConsumerMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumer_arn ⇒ String
The Amazon Resource Name (ARN) of the consumer namespace that returns in the list of datashares.
-
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records.
-
#max_records ⇒ Integer
The maximum number of response records to return in each call.
-
#status ⇒ String
An identifier giving the status of a datashare in the consumer cluster.
Instance Attribute Details
#consumer_arn ⇒ String
The Amazon Resource Name (ARN) of the consumer namespace that returns in the list of datashares.
4536 4537 4538 4539 4540 4541 4542 4543 |
# File 'lib/aws-sdk-redshift/types.rb', line 4536 class DescribeDataSharesForConsumerMessage < Struct.new( :consumer_arn, :status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeDataSharesForConsumer request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.
4536 4537 4538 4539 4540 4541 4542 4543 |
# File 'lib/aws-sdk-redshift/types.rb', line 4536 class DescribeDataSharesForConsumerMessage < Struct.new( :consumer_arn, :status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.
4536 4537 4538 4539 4540 4541 4542 4543 |
# File 'lib/aws-sdk-redshift/types.rb', line 4536 class DescribeDataSharesForConsumerMessage < Struct.new( :consumer_arn, :status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
An identifier giving the status of a datashare in the consumer cluster. If this field is specified, Amazon Redshift returns the list of datashares that have the specified status.
4536 4537 4538 4539 4540 4541 4542 4543 |
# File 'lib/aws-sdk-redshift/types.rb', line 4536 class DescribeDataSharesForConsumerMessage < Struct.new( :consumer_arn, :status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |