Class: Aws::Redshift::Types::DescribeDataSharesForConsumerResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeDataSharesForConsumerResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_shares ⇒ Array<Types::DataShare>
Shows the results of datashares available for consumers.
-
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records.
Instance Attribute Details
#data_shares ⇒ Array<Types::DataShare>
Shows the results of datashares available for consumers.
4746 4747 4748 4749 4750 4751 |
# File 'lib/aws-sdk-redshift/types.rb', line 4746 class DescribeDataSharesForConsumerResult < Struct.new( :data_shares, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional parameter that specifies the starting point to return a
set of response records. When the results of a
DescribeDataSharesForConsumer request exceed the value specified in
MaxRecords, Amazon Web Services returns a value in the Marker
field of the response. You can retrieve the next set of response
records by providing the returned marker value in the Marker
parameter and retrying the request.
4746 4747 4748 4749 4750 4751 |
# File 'lib/aws-sdk-redshift/types.rb', line 4746 class DescribeDataSharesForConsumerResult < Struct.new( :data_shares, :marker) SENSITIVE = [] include Aws::Structure end |