Class: Aws::Redshift::Types::DescribeDataSharesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeDataSharesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_shares ⇒ Array<Types::DataShare>
The results returned from describing datashares.
-
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records.
Instance Attribute Details
#data_shares ⇒ Array<Types::DataShare>
The results returned from describing datashares.
4805 4806 4807 4808 4809 4810 |
# File 'lib/aws-sdk-redshift/types.rb', line 4805 class DescribeDataSharesResult < Struct.new( :data_shares, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeDataShares request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.
4805 4806 4807 4808 4809 4810 |
# File 'lib/aws-sdk-redshift/types.rb', line 4805 class DescribeDataSharesResult < Struct.new( :data_shares, :marker) SENSITIVE = [] include Aws::Structure end |