Class: Aws::Redshift::Types::DescribeIntegrationsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::DescribeIntegrationsFilter>

A filter that specifies one or more resources to return.



5413
5414
5415
5416
5417
5418
5419
5420
# File 'lib/aws-sdk-redshift/types.rb', line 5413

class DescribeIntegrationsMessage < Struct.new(
  :integration_arn,
  :max_records,
  :marker,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#integration_arnString

The unique identifier of the integration.



5413
5414
5415
5416
5417
5418
5419
5420
# File 'lib/aws-sdk-redshift/types.rb', line 5413

class DescribeIntegrationsMessage < Struct.new(
  :integration_arn,
  :max_records,
  :marker,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DescribeIntegrations request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



5413
5414
5415
5416
5417
5418
5419
5420
# File 'lib/aws-sdk-redshift/types.rb', line 5413

class DescribeIntegrationsMessage < Struct.new(
  :integration_arn,
  :max_records,
  :marker,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.

Default: 100

Constraints: minimum 20, maximum 100.



5413
5414
5415
5416
5417
5418
5419
5420
# File 'lib/aws-sdk-redshift/types.rb', line 5413

class DescribeIntegrationsMessage < Struct.new(
  :integration_arn,
  :max_records,
  :marker,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end