Class: Aws::Redshift::Types::DescribeQev2IdcApplicationsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


5622
5623
5624
5625
5626
5627
5628
# File 'lib/aws-sdk-redshift/types.rb', line 5622

class DescribeQev2IdcApplicationsMessage < Struct.new(
  :qev_2_idc_application_arn,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.

Returns:

  • (Integer)


5622
5623
5624
5625
5626
5627
5628
# File 'lib/aws-sdk-redshift/types.rb', line 5622

class DescribeQev2IdcApplicationsMessage < Struct.new(
  :qev_2_idc_application_arn,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#qev_2_idc_application_arnString

The Amazon Resource Name (ARN) for the Amazon Redshift Query Editor (QEV2) application that integrates with IAM Identity Center.

Returns:

  • (String)


5622
5623
5624
5625
5626
5627
5628
# File 'lib/aws-sdk-redshift/types.rb', line 5622

class DescribeQev2IdcApplicationsMessage < Struct.new(
  :qev_2_idc_application_arn,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end