Class: Aws::Redshift::Types::DescribeQev2IdcApplicationsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


5646
5647
5648
5649
5650
5651
# File 'lib/aws-sdk-redshift/types.rb', line 5646

class DescribeQev2IdcApplicationsResult < Struct.new(
  :qev_2_idc_applications,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#qev_2_idc_applicationsArray<Types::Qev2IdcApplication>

The list of Amazon Redshift Query Editor (QEV2) IAM Identity Center applications.

Returns:



5646
5647
5648
5649
5650
5651
# File 'lib/aws-sdk-redshift/types.rb', line 5646

class DescribeQev2IdcApplicationsResult < Struct.new(
  :qev_2_idc_applications,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end