Class: Aws::Redshift::Types::DescribeReservedNodesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeReservedNodesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records.
-
#max_records ⇒ Integer
The maximum number of response records to return in each call.
-
#reserved_node_id ⇒ String
Identifier for the node reservation.
Instance Attribute Details
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeReservedNodes request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.
5582 5583 5584 5585 5586 5587 5588 |
# File 'lib/aws-sdk-redshift/types.rb', line 5582 class DescribeReservedNodesMessage < Struct.new( :reserved_node_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.
Default: 100
Constraints: minimum 20, maximum 100.
5582 5583 5584 5585 5586 5587 5588 |
# File 'lib/aws-sdk-redshift/types.rb', line 5582 class DescribeReservedNodesMessage < Struct.new( :reserved_node_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#reserved_node_id ⇒ String
Identifier for the node reservation.
5582 5583 5584 5585 5586 5587 5588 |
# File 'lib/aws-sdk-redshift/types.rb', line 5582 class DescribeReservedNodesMessage < Struct.new( :reserved_node_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |