Class: Aws::Redshift::Types::DescribeScheduledActionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activeBoolean

If true, retrieve only active scheduled actions. If false, retrieve only disabled scheduled actions.

Returns:

  • (Boolean)


5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'lib/aws-sdk-redshift/types.rb', line 5899

class DescribeScheduledActionsMessage < Struct.new(
  :scheduled_action_name,
  :target_action_type,
  :start_time,
  :end_time,
  :active,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end time in UTC of the scheduled action to retrieve. Only active scheduled actions that have invocations before this time are retrieved.

Returns:

  • (Time)


5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'lib/aws-sdk-redshift/types.rb', line 5899

class DescribeScheduledActionsMessage < Struct.new(
  :scheduled_action_name,
  :target_action_type,
  :start_time,
  :end_time,
  :active,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::ScheduledActionFilter>

List of scheduled action filters.

Returns:



5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'lib/aws-sdk-redshift/types.rb', line 5899

class DescribeScheduledActionsMessage < Struct.new(
  :scheduled_action_name,
  :target_action_type,
  :start_time,
  :end_time,
  :active,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeScheduledActions request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.

Returns:

  • (String)


5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'lib/aws-sdk-redshift/types.rb', line 5899

class DescribeScheduledActionsMessage < Struct.new(
  :scheduled_action_name,
  :target_action_type,
  :start_time,
  :end_time,
  :active,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.

Default: 100

Constraints: minimum 20, maximum 100.

Returns:

  • (Integer)


5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'lib/aws-sdk-redshift/types.rb', line 5899

class DescribeScheduledActionsMessage < Struct.new(
  :scheduled_action_name,
  :target_action_type,
  :start_time,
  :end_time,
  :active,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_action_nameString

The name of the scheduled action to retrieve.

Returns:

  • (String)


5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'lib/aws-sdk-redshift/types.rb', line 5899

class DescribeScheduledActionsMessage < Struct.new(
  :scheduled_action_name,
  :target_action_type,
  :start_time,
  :end_time,
  :active,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start time in UTC of the scheduled actions to retrieve. Only active scheduled actions that have invocations after this time are retrieved.

Returns:

  • (Time)


5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'lib/aws-sdk-redshift/types.rb', line 5899

class DescribeScheduledActionsMessage < Struct.new(
  :scheduled_action_name,
  :target_action_type,
  :start_time,
  :end_time,
  :active,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#target_action_typeString

The type of the scheduled actions to retrieve.

Returns:

  • (String)


5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'lib/aws-sdk-redshift/types.rb', line 5899

class DescribeScheduledActionsMessage < Struct.new(
  :scheduled_action_name,
  :target_action_type,
  :start_time,
  :end_time,
  :active,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end