Method: Aws::Redshift::Types::DescribeSnapshotCopyGrantsMessage#marker

Defined in:
lib/aws-sdk-redshift/types.rb

#markerString

An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeSnapshotCopyGrant request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.

Constraints: You can specify either the SnapshotCopyGrantName parameter or the Marker parameter, but not both.

Returns:

  • (String)


5849
5850
5851
5852
5853
5854
5855
5856
5857
# File 'lib/aws-sdk-redshift/types.rb', line 5849

class DescribeSnapshotCopyGrantsMessage < Struct.new(
  :snapshot_copy_grant_name,
  :max_records,
  :marker,
  :tag_keys,
  :tag_values)
  SENSITIVE = []
  include Aws::Structure
end