Class: Aws::Redshift::Types::DescribeSnapshotSchedulesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeSnapshotSchedulesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_identifier ⇒ String
The unique identifier for the cluster whose snapshot schedules you want to view.
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#max_records ⇒ Integer
The maximum number or response records to return in each call.
-
#schedule_identifier ⇒ String
A unique identifier for a snapshot schedule.
-
#tag_keys ⇒ Array<String>
The key value for a snapshot schedule tag.
-
#tag_values ⇒ Array<String>
The value corresponding to the key of the snapshot schedule tag.
Instance Attribute Details
#cluster_identifier ⇒ String
The unique identifier for the cluster whose snapshot schedules you want to view.
6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 |
# File 'lib/aws-sdk-redshift/types.rb', line 6010 class DescribeSnapshotSchedulesMessage < Struct.new( :cluster_identifier, :schedule_identifier, :tag_keys, :tag_values, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A value that indicates the starting point for the next set of
response records in a subsequent request. If a value is returned in
a response, you can retrieve the next set of records by providing
this returned marker value in the marker parameter and retrying
the command. If the marker field is empty, all response records
have been retrieved for the request.
6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 |
# File 'lib/aws-sdk-redshift/types.rb', line 6010 class DescribeSnapshotSchedulesMessage < Struct.new( :cluster_identifier, :schedule_identifier, :tag_keys, :tag_values, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number or response records to return in each call. If
the number of remaining response records exceeds the specified
MaxRecords value, a value is returned in a marker field of the
response. You can retrieve the next set of records by retrying the
command with the returned marker value.
6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 |
# File 'lib/aws-sdk-redshift/types.rb', line 6010 class DescribeSnapshotSchedulesMessage < Struct.new( :cluster_identifier, :schedule_identifier, :tag_keys, :tag_values, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#schedule_identifier ⇒ String
A unique identifier for a snapshot schedule.
6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 |
# File 'lib/aws-sdk-redshift/types.rb', line 6010 class DescribeSnapshotSchedulesMessage < Struct.new( :cluster_identifier, :schedule_identifier, :tag_keys, :tag_values, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#tag_keys ⇒ Array<String>
The key value for a snapshot schedule tag.
6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 |
# File 'lib/aws-sdk-redshift/types.rb', line 6010 class DescribeSnapshotSchedulesMessage < Struct.new( :cluster_identifier, :schedule_identifier, :tag_keys, :tag_values, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#tag_values ⇒ Array<String>
The value corresponding to the key of the snapshot schedule tag.
6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 |
# File 'lib/aws-sdk-redshift/types.rb', line 6010 class DescribeSnapshotSchedulesMessage < Struct.new( :cluster_identifier, :schedule_identifier, :tag_keys, :tag_values, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |