Class: Aws::Redshift::Types::DescribeSnapshotSchedulesOutputMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeSnapshotSchedulesOutputMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#snapshot_schedules ⇒ Array<Types::SnapshotSchedule>
A list of SnapshotSchedules.
Instance Attribute Details
#marker ⇒ String
A value that indicates the starting point for the next set of
response records in a subsequent request. If a value is returned in
a response, you can retrieve the next set of records by providing
this returned marker value in the marker parameter and retrying
the command. If the marker field is empty, all response records
have been retrieved for the request.
6036 6037 6038 6039 6040 6041 |
# File 'lib/aws-sdk-redshift/types.rb', line 6036 class DescribeSnapshotSchedulesOutputMessage < Struct.new( :snapshot_schedules, :marker) SENSITIVE = [] include Aws::Structure end |
#snapshot_schedules ⇒ Array<Types::SnapshotSchedule>
A list of SnapshotSchedules.
6036 6037 6038 6039 6040 6041 |
# File 'lib/aws-sdk-redshift/types.rb', line 6036 class DescribeSnapshotSchedulesOutputMessage < Struct.new( :snapshot_schedules, :marker) SENSITIVE = [] include Aws::Structure end |