Class: Aws::Redshift::Types::EnableLoggingMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_nameString

The name of an existing S3 bucket where the log files are to be stored.

Constraints:

  • Must be in the same region as the cluster

  • The cluster must have read bucket and put object permissions

Returns:

  • (String)


6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
# File 'lib/aws-sdk-redshift/types.rb', line 6446

class EnableLoggingMessage < Struct.new(
  :cluster_identifier,
  :bucket_name,
  :s3_key_prefix,
  :log_destination_type,
  :log_exports,
  :s3_table_kms_key_id,
  :s3_table_granularity)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_identifierString

The identifier of the cluster on which logging is to be started.

Example: examplecluster

Returns:

  • (String)


6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
# File 'lib/aws-sdk-redshift/types.rb', line 6446

class EnableLoggingMessage < Struct.new(
  :cluster_identifier,
  :bucket_name,
  :s3_key_prefix,
  :log_destination_type,
  :log_exports,
  :s3_table_kms_key_id,
  :s3_table_granularity)
  SENSITIVE = []
  include Aws::Structure
end

#log_destination_typeString

The log destination type. An enum with possible values of s3, cloudwatch, and s3table.

Returns:

  • (String)


6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
# File 'lib/aws-sdk-redshift/types.rb', line 6446

class EnableLoggingMessage < Struct.new(
  :cluster_identifier,
  :bucket_name,
  :s3_key_prefix,
  :log_destination_type,
  :log_exports,
  :s3_table_kms_key_id,
  :s3_table_granularity)
  SENSITIVE = []
  include Aws::Structure
end

#log_exportsArray<String>

The collection of exported log types. When LogDestinationType is s3 or cloudwatch, possible values are connectionlog, useractivitylog, and userlog. When LogDestinationType is s3table, the values are the names of the system tables to publish. Omitting this parameter, passing an empty list, or including the value all publishes all current and future system tables.

Returns:

  • (Array<String>)


6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
# File 'lib/aws-sdk-redshift/types.rb', line 6446

class EnableLoggingMessage < Struct.new(
  :cluster_identifier,
  :bucket_name,
  :s3_key_prefix,
  :log_destination_type,
  :log_exports,
  :s3_table_kms_key_id,
  :s3_table_granularity)
  SENSITIVE = []
  include Aws::Structure
end

#s3_key_prefixString

The prefix applied to the log file names.

Valid characters are any letter from any language, any whitespace character, any numeric character, and the following characters: underscore (_), period (.), colon (:), slash (/), equal (=), plus (+), backslash (``), hyphen (-), at symbol (@).

Returns:

  • (String)


6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
# File 'lib/aws-sdk-redshift/types.rb', line 6446

class EnableLoggingMessage < Struct.new(
  :cluster_identifier,
  :bucket_name,
  :s3_key_prefix,
  :log_destination_type,
  :log_exports,
  :s3_table_kms_key_id,
  :s3_table_granularity)
  SENSITIVE = []
  include Aws::Structure
end

#s3_table_granularityString

The scope of system table publishing. Valid values are cluster and account. A value of cluster scopes publishing to the individual cluster. A value of account scopes publishing to the Amazon Web Services account. This parameter is valid only when LogDestinationType is s3table.

Returns:

  • (String)


6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
# File 'lib/aws-sdk-redshift/types.rb', line 6446

class EnableLoggingMessage < Struct.new(
  :cluster_identifier,
  :bucket_name,
  :s3_key_prefix,
  :log_destination_type,
  :log_exports,
  :s3_table_kms_key_id,
  :s3_table_granularity)
  SENSITIVE = []
  include Aws::Structure
end

#s3_table_kms_key_idString

The identifier of a customer managed KMS key used to encrypt the S3 tables. This parameter is valid only when LogDestinationType is s3table.

Returns:

  • (String)


6446
6447
6448
6449
6450
6451
6452
6453
6454
6455
6456
# File 'lib/aws-sdk-redshift/types.rb', line 6446

class EnableLoggingMessage < Struct.new(
  :cluster_identifier,
  :bucket_name,
  :s3_key_prefix,
  :log_destination_type,
  :log_exports,
  :s3_table_kms_key_id,
  :s3_table_granularity)
  SENSITIVE = []
  include Aws::Structure
end