Class: Aws::Redshift::Types::EndpointAccessList
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::EndpointAccessList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint_access_list ⇒ Array<Types::EndpointAccess>
The list of endpoints with access to the cluster.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeEndpointAccessrequest.
Instance Attribute Details
#endpoint_access_list ⇒ Array<Types::EndpointAccess>
The list of endpoints with access to the cluster.
6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-redshift/types.rb', line 6624 class EndpointAccessList < Struct.new( :endpoint_access_list, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeEndpointAccess request. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by the MaxRecords parameter.
6624 6625 6626 6627 6628 6629 |
# File 'lib/aws-sdk-redshift/types.rb', line 6624 class EndpointAccessList < Struct.new( :endpoint_access_list, :marker) SENSITIVE = [] include Aws::Structure end |