Class: Aws::Redshift::Types::EventSubscription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Describes event subscriptions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cust_subscription_idString

The name of the Amazon Redshift event notification subscription.



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#customer_aws_idString

The Amazon Web Services account associated with the Amazon Redshift event notification subscription.



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

A boolean value indicating whether the subscription is enabled; true indicates that the subscription is enabled.



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#event_categories_listArray<String>

The list of Amazon Redshift event categories specified in the event notification subscription.

Values: Configuration, Management, Monitoring, Security, Pending



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

The event severity specified in the Amazon Redshift event notification subscription.

Values: ERROR, INFO



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_arnString

The Amazon Resource Name (ARN) of the Amazon SNS topic used by the event notification subscription.



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#source_ids_listArray<String>

A list of the sources that publish events to the Amazon Redshift event notification subscription.



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The source type of the events returned by the Amazon Redshift event notification, such as cluster, cluster-snapshot, cluster-parameter-group, cluster-security-group, or scheduled-action.



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Amazon Redshift event notification subscription.

Constraints:

  • Can be one of the following: active \| no-permission \| topic-not-exist

  • The status “no-permission” indicates that Amazon Redshift no longer has permission to post to the Amazon SNS topic. The status “topic-not-exist” indicates that the topic was deleted after the subscription was created.



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_creation_timeTime

The date and time the Amazon Redshift event notification subscription was created.



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The list of tags for the event subscription.



6535
6536
6537
6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/aws-sdk-redshift/types.rb', line 6535

class EventSubscription < Struct.new(
  :customer_aws_id,
  :cust_subscription_id,
  :sns_topic_arn,
  :status,
  :subscription_creation_time,
  :source_type,
  :source_ids_list,
  :event_categories_list,
  :severity,
  :enabled,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end