Class: Aws::Redshift::Types::EventSubscriptionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::EventSubscriptionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_subscriptions_list ⇒ Array<Types::EventSubscription>
A list of event subscriptions.
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
Instance Attribute Details
#event_subscriptions_list ⇒ Array<Types::EventSubscription>
A list of event subscriptions.
6699 6700 6701 6702 6703 6704 |
# File 'lib/aws-sdk-redshift/types.rb', line 6699 class EventSubscriptionsMessage < Struct.new( :marker, :event_subscriptions_list) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.
6699 6700 6701 6702 6703 6704 |
# File 'lib/aws-sdk-redshift/types.rb', line 6699 class EventSubscriptionsMessage < Struct.new( :marker, :event_subscriptions_list) SENSITIVE = [] include Aws::Structure end |