Class: Aws::Redshift::Types::GetClusterCredentialsWithIAMMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

The unique identifier of the cluster that contains the database for which you are requesting credentials.

Returns:

  • (String)


7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-redshift/types.rb', line 7142

class GetClusterCredentialsWithIAMMessage < Struct.new(
  :db_name,
  :cluster_identifier,
  :duration_seconds,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#custom_domain_nameString

The custom domain name for the IAM message cluster credentials.

Returns:

  • (String)


7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-redshift/types.rb', line 7142

class GetClusterCredentialsWithIAMMessage < Struct.new(
  :db_name,
  :cluster_identifier,
  :duration_seconds,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#db_nameString

The name of the database for which you are requesting credentials. If the database name is specified, the IAM policy must allow access to the resource dbname for the specified database name. If the database name is not specified, access to all databases is allowed.

Returns:

  • (String)


7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-redshift/types.rb', line 7142

class GetClusterCredentialsWithIAMMessage < Struct.new(
  :db_name,
  :cluster_identifier,
  :duration_seconds,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#duration_secondsInteger

The number of seconds until the returned temporary password expires.

Range: 900-3600. Default: 900.

Returns:

  • (Integer)


7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-redshift/types.rb', line 7142

class GetClusterCredentialsWithIAMMessage < Struct.new(
  :db_name,
  :cluster_identifier,
  :duration_seconds,
  :custom_domain_name)
  SENSITIVE = []
  include Aws::Structure
end