Class: Aws::Redshift::Types::GetIdentityCenterAuthTokenRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

The request parameters for ‘GetIdentityCenterAuthToken`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_idsArray<String>

A list of cluster identifiers that the generated token can be used with. The token will be scoped to only allow authentication to the specified clusters.

Constraints:

  • ‘ClusterIds` must contain at least 1 cluster identifier.

  • ‘ClusterIds` can hold a maximum of 20 cluster identifiers.

  • Cluster identifiers must be 1 to 63 characters in length.

  • The characters accepted for cluster identifiers are the following:

    • Alphanumeric characters

    • Hyphens

  • Cluster identifiers must start with a letter.

  • Cluster identifiers can’t end with a hyphen or contain two consecutive hyphens.

Returns:

  • (Array<String>)


7045
7046
7047
7048
7049
# File 'lib/aws-sdk-redshift/types.rb', line 7045

class GetIdentityCenterAuthTokenRequest < Struct.new(
  :cluster_ids)
  SENSITIVE = []
  include Aws::Structure
end