Class: Aws::Redshift::Types::GetIdentityCenterAuthTokenResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

The response from GetIdentityCenterAuthToken containing the encrypted authentication token and expiration time.

Constant Summary collapse

SENSITIVE =
[:token]

Instance Attribute Summary collapse

Instance Attribute Details

#expiration_timeTime

The time (UTC) when the token expires. After this timestamp, the token will no longer be valid for authentication.

Returns:

  • (Time)


7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-redshift/types.rb', line 7204

class GetIdentityCenterAuthTokenResponse < Struct.new(
  :token,
  :expiration_time)
  SENSITIVE = [:token]
  include Aws::Structure
end

#tokenString

The encrypted authentication token containing the caller's Amazon Web Services IAM Identity Center identity information. This token is encrypted using Key Management Service and can only be decrypted by the specified Amazon Redshift clusters. Use this token with Amazon Redshift drivers to authenticate using your Amazon Web Services IAM Identity Center identity.

Returns:

  • (String)


7204
7205
7206
7207
7208
7209
# File 'lib/aws-sdk-redshift/types.rb', line 7204

class GetIdentityCenterAuthTokenResponse < Struct.new(
  :token,
  :expiration_time)
  SENSITIVE = [:token]
  include Aws::Structure
end