Class: Aws::Redshift::Types::GetReservedNodeExchangeConfigurationOptionsOutputMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::GetReservedNodeExchangeConfigurationOptionsOutputMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A pagination token provided by a previous
GetReservedNodeExchangeConfigurationOptionsrequest. -
#reserved_node_configuration_option_list ⇒ Array<Types::ReservedNodeConfigurationOption>
the configuration options for the reserved-node exchange.
Instance Attribute Details
#marker ⇒ String
A pagination token provided by a previous
GetReservedNodeExchangeConfigurationOptions request.
7312 7313 7314 7315 7316 7317 |
# File 'lib/aws-sdk-redshift/types.rb', line 7312 class GetReservedNodeExchangeConfigurationOptionsOutputMessage < Struct.new( :marker, :reserved_node_configuration_option_list) SENSITIVE = [] include Aws::Structure end |
#reserved_node_configuration_option_list ⇒ Array<Types::ReservedNodeConfigurationOption>
the configuration options for the reserved-node exchange. These options include information about the source reserved node and target reserved node. Details include the node type, the price, the node count, and the offering type.
7312 7313 7314 7315 7316 7317 |
# File 'lib/aws-sdk-redshift/types.rb', line 7312 class GetReservedNodeExchangeConfigurationOptionsOutputMessage < Struct.new( :marker, :reserved_node_configuration_option_list) SENSITIVE = [] include Aws::Structure end |