Class: Aws::Redshift::Types::HsmClientCertificate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Returns information about an HSM client certificate. The certificate is stored in a secure Hardware Storage Module (HSM), and used by the Amazon Redshift cluster to encrypt data files.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#hsm_client_certificate_identifierString

The identifier of the HSM client certificate.



7254
7255
7256
7257
7258
7259
7260
# File 'lib/aws-sdk-redshift/types.rb', line 7254

class HsmClientCertificate < Struct.new(
  :hsm_client_certificate_identifier,
  :hsm_client_certificate_public_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#hsm_client_certificate_public_keyString

The public key that the Amazon Redshift cluster will use to connect to the HSM. You must register the public key in the HSM.



7254
7255
7256
7257
7258
7259
7260
# File 'lib/aws-sdk-redshift/types.rb', line 7254

class HsmClientCertificate < Struct.new(
  :hsm_client_certificate_identifier,
  :hsm_client_certificate_public_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The list of tags for the HSM client certificate.



7254
7255
7256
7257
7258
7259
7260
# File 'lib/aws-sdk-redshift/types.rb', line 7254

class HsmClientCertificate < Struct.new(
  :hsm_client_certificate_identifier,
  :hsm_client_certificate_public_key,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end