Class: Aws::Redshift::Types::HsmClientCertificateMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::HsmClientCertificateMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hsm_client_certificates ⇒ Array<Types::HsmClientCertificate>
A list of the identifiers for one or more HSM client certificates used by Amazon Redshift clusters to store and retrieve database encryption keys in an HSM.
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
Instance Attribute Details
#hsm_client_certificates ⇒ Array<Types::HsmClientCertificate>
A list of the identifiers for one or more HSM client certificates used by Amazon Redshift clusters to store and retrieve database encryption keys in an HSM.
7401 7402 7403 7404 7405 7406 |
# File 'lib/aws-sdk-redshift/types.rb', line 7401 class HsmClientCertificateMessage < Struct.new( :marker, :hsm_client_certificates) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A value that indicates the starting point for the next set of
response records in a subsequent request. If a value is returned in
a response, you can retrieve the next set of records by providing
this returned marker value in the Marker parameter and retrying
the command. If the Marker field is empty, all response records
have been retrieved for the request.
7401 7402 7403 7404 7405 7406 |
# File 'lib/aws-sdk-redshift/types.rb', line 7401 class HsmClientCertificateMessage < Struct.new( :marker, :hsm_client_certificates) SENSITIVE = [] include Aws::Structure end |