Class: Aws::Redshift::Types::HsmStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::HsmStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Describes the status of changes to HSM settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hsm_client_certificate_identifier ⇒ String
Specifies the name of the HSM client certificate the Amazon Redshift cluster uses to retrieve the data encryption keys stored in an HSM.
-
#hsm_configuration_identifier ⇒ String
Specifies the name of the HSM configuration that contains the information the Amazon Redshift cluster can use to retrieve and store keys in an HSM.
-
#status ⇒ String
Reports whether the Amazon Redshift cluster has finished applying any HSM settings changes specified in a modify cluster command.
Instance Attribute Details
#hsm_client_certificate_identifier ⇒ String
Specifies the name of the HSM client certificate the Amazon Redshift cluster uses to retrieve the data encryption keys stored in an HSM.
7536 7537 7538 7539 7540 7541 7542 |
# File 'lib/aws-sdk-redshift/types.rb', line 7536 class HsmStatus < Struct.new( :hsm_client_certificate_identifier, :hsm_configuration_identifier, :status) SENSITIVE = [] include Aws::Structure end |
#hsm_configuration_identifier ⇒ String
Specifies the name of the HSM configuration that contains the information the Amazon Redshift cluster can use to retrieve and store keys in an HSM.
7536 7537 7538 7539 7540 7541 7542 |
# File 'lib/aws-sdk-redshift/types.rb', line 7536 class HsmStatus < Struct.new( :hsm_client_certificate_identifier, :hsm_configuration_identifier, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Reports whether the Amazon Redshift cluster has finished applying any HSM settings changes specified in a modify cluster command.
Values: active, applying
7536 7537 7538 7539 7540 7541 7542 |
# File 'lib/aws-sdk-redshift/types.rb', line 7536 class HsmStatus < Struct.new( :hsm_client_certificate_identifier, :hsm_configuration_identifier, :status) SENSITIVE = [] include Aws::Structure end |