Class: Aws::Redshift::Types::InboundIntegrationsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::InboundIntegrationsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inbound_integrations ⇒ Array<Types::InboundIntegration>
A list of InboundIntegration instances.
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
Instance Attribute Details
#inbound_integrations ⇒ Array<Types::InboundIntegration>
A list of InboundIntegration instances.
7675 7676 7677 7678 7679 7680 |
# File 'lib/aws-sdk-redshift/types.rb', line 7675 class InboundIntegrationsMessage < Struct.new( :marker, :inbound_integrations) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A value that indicates the starting point for the next set of
response records in a subsequent request. If a value is returned in
a response, you can retrieve the next set of records by providing
this returned marker value in the Marker parameter and retrying
the command. If the Marker field is empty, all response records
have been retrieved for the request.
7675 7676 7677 7678 7679 7680 |
# File 'lib/aws-sdk-redshift/types.rb', line 7675 class InboundIntegrationsMessage < Struct.new( :marker, :inbound_integrations) SENSITIVE = [] include Aws::Structure end |