Class: Aws::Redshift::Types::Integration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_encryption_contextHash<String,String>

The encryption context for the integration. For more information, see Encryption context in the Amazon Web Services Key Management Service Developer Guide.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time (UTC) when the integration was created.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the integration.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#errorsArray<Types::IntegrationError>

Any errors associated with the integration.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#integration_arnString

The Amazon Resource Name (ARN) of the integration.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#integration_nameString

The name of the integration.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Key Management Service (KMS) key identifier for the key used to encrypt the integration.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The Amazon Resource Name (ARN) of the database used as the source for replication.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the integration.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The list of tags associated with the integration.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The Amazon Resource Name (ARN) of the Amazon Redshift data warehouse to use as the target for replication.



7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
7768
7769
7770
7771
# File 'lib/aws-sdk-redshift/types.rb', line 7757

class Integration < Struct.new(
  :integration_arn,
  :integration_name,
  :source_arn,
  :target_arn,
  :status,
  :errors,
  :create_time,
  :description,
  :kms_key_id,
  :additional_encryption_context,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end