Class: Aws::Redshift::Types::IntegrationsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::IntegrationsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#integrations ⇒ Array<Types::Integration>
List of integrations that are described.
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
Instance Attribute Details
#integrations ⇒ Array<Types::Integration>
List of integrations that are described.
7854 7855 7856 7857 7858 7859 |
# File 'lib/aws-sdk-redshift/types.rb', line 7854 class IntegrationsMessage < Struct.new( :marker, :integrations) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A value that indicates the starting point for the next set of
response records in a subsequent request. If a value is returned in
a response, you can retrieve the next set of records by providing
this returned marker value in the Marker parameter and retrying
the command. If the Marker field is empty, all response records
have been retrieved for the request.
7854 7855 7856 7857 7858 7859 |
# File 'lib/aws-sdk-redshift/types.rb', line 7854 class IntegrationsMessage < Struct.new( :marker, :integrations) SENSITIVE = [] include Aws::Structure end |