Class: Aws::Redshift::Types::ListRecommendationsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-redshift/types.rb', line 8220

class ListRecommendationsResult < Struct.new(
  :recommendations,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#recommendationsArray<Types::Recommendation>

The Advisor recommendations for action on the Amazon Redshift cluster.

Returns:



8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-redshift/types.rb', line 8220

class ListRecommendationsResult < Struct.new(
  :recommendations,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end