Class: Aws::Redshift::Types::LoggingStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Describes the status of logging for a cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_nameString

The name of the S3 bucket where the log files are stored.

Returns:

  • (String)


8287
8288
8289
8290
8291
8292
8293
8294
8295
8296
8297
8298
8299
# File 'lib/aws-sdk-redshift/types.rb', line 8287

class LoggingStatus < Struct.new(
  :logging_enabled,
  :bucket_name,
  :s3_key_prefix,
  :last_successful_delivery_time,
  :last_failure_time,
  :last_failure_message,
  :log_destination_type,
  :log_exports,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#last_failure_messageString

The message indicating that logs failed to be delivered.

Returns:

  • (String)


8287
8288
8289
8290
8291
8292
8293
8294
8295
8296
8297
8298
8299
# File 'lib/aws-sdk-redshift/types.rb', line 8287

class LoggingStatus < Struct.new(
  :logging_enabled,
  :bucket_name,
  :s3_key_prefix,
  :last_successful_delivery_time,
  :last_failure_time,
  :last_failure_message,
  :log_destination_type,
  :log_exports,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#last_failure_timeTime

The last time when logs failed to be delivered.

Returns:

  • (Time)


8287
8288
8289
8290
8291
8292
8293
8294
8295
8296
8297
8298
8299
# File 'lib/aws-sdk-redshift/types.rb', line 8287

class LoggingStatus < Struct.new(
  :logging_enabled,
  :bucket_name,
  :s3_key_prefix,
  :last_successful_delivery_time,
  :last_failure_time,
  :last_failure_message,
  :log_destination_type,
  :log_exports,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#last_successful_delivery_timeTime

The last time that logs were delivered.

Returns:

  • (Time)


8287
8288
8289
8290
8291
8292
8293
8294
8295
8296
8297
8298
8299
# File 'lib/aws-sdk-redshift/types.rb', line 8287

class LoggingStatus < Struct.new(
  :logging_enabled,
  :bucket_name,
  :s3_key_prefix,
  :last_successful_delivery_time,
  :last_failure_time,
  :last_failure_message,
  :log_destination_type,
  :log_exports,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#log_destination_typeString

The log destination type. An enum with possible values of s3, cloudwatch, and s3table.

Returns:

  • (String)


8287
8288
8289
8290
8291
8292
8293
8294
8295
8296
8297
8298
8299
# File 'lib/aws-sdk-redshift/types.rb', line 8287

class LoggingStatus < Struct.new(
  :logging_enabled,
  :bucket_name,
  :s3_key_prefix,
  :last_successful_delivery_time,
  :last_failure_time,
  :last_failure_message,
  :log_destination_type,
  :log_exports,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#log_exportsArray<String>

The collection of exported log types. When LogDestinationType is s3 or cloudwatch, possible values are connectionlog, useractivitylog, and userlog. When LogDestinationType is s3table, the values are the names of the system tables being published.

Returns:

  • (Array<String>)


8287
8288
8289
8290
8291
8292
8293
8294
8295
8296
8297
8298
8299
# File 'lib/aws-sdk-redshift/types.rb', line 8287

class LoggingStatus < Struct.new(
  :logging_enabled,
  :bucket_name,
  :s3_key_prefix,
  :last_successful_delivery_time,
  :last_failure_time,
  :last_failure_message,
  :log_destination_type,
  :log_exports,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#logging_enabledBoolean

true if logging is on, false if logging is off.

Returns:

  • (Boolean)


8287
8288
8289
8290
8291
8292
8293
8294
8295
8296
8297
8298
8299
# File 'lib/aws-sdk-redshift/types.rb', line 8287

class LoggingStatus < Struct.new(
  :logging_enabled,
  :bucket_name,
  :s3_key_prefix,
  :last_successful_delivery_time,
  :last_failure_time,
  :last_failure_message,
  :log_destination_type,
  :log_exports,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#s3_key_prefixString

The prefix applied to the log file names.

Returns:

  • (String)


8287
8288
8289
8290
8291
8292
8293
8294
8295
8296
8297
8298
8299
# File 'lib/aws-sdk-redshift/types.rb', line 8287

class LoggingStatus < Struct.new(
  :logging_enabled,
  :bucket_name,
  :s3_key_prefix,
  :last_successful_delivery_time,
  :last_failure_time,
  :last_failure_message,
  :log_destination_type,
  :log_exports,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end

#s3_tablesTypes::S3TablePublishStatus

The status of system table publishing to S3 Tables. This field is populated only when system table publishing is active.



8287
8288
8289
8290
8291
8292
8293
8294
8295
8296
8297
8298
8299
# File 'lib/aws-sdk-redshift/types.rb', line 8287

class LoggingStatus < Struct.new(
  :logging_enabled,
  :bucket_name,
  :s3_key_prefix,
  :last_successful_delivery_time,
  :last_failure_time,
  :last_failure_message,
  :log_destination_type,
  :log_exports,
  :s3_tables)
  SENSITIVE = []
  include Aws::Structure
end