Class: Aws::Redshift::Types::ModifyCustomDomainAssociationMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

The identifier of the cluster to change a custom domain association for.

Returns:

  • (String)


9000
9001
9002
9003
9004
9005
9006
# File 'lib/aws-sdk-redshift/types.rb', line 9000

class ModifyCustomDomainAssociationMessage < Struct.new(
  :custom_domain_name,
  :custom_domain_certificate_arn,
  :cluster_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#custom_domain_certificate_arnString

The certificate Amazon Resource Name (ARN) for the changed custom domain association.

Returns:

  • (String)


9000
9001
9002
9003
9004
9005
9006
# File 'lib/aws-sdk-redshift/types.rb', line 9000

class ModifyCustomDomainAssociationMessage < Struct.new(
  :custom_domain_name,
  :custom_domain_certificate_arn,
  :cluster_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#custom_domain_nameString

The custom domain name for a changed custom domain association.

Returns:

  • (String)


9000
9001
9002
9003
9004
9005
9006
# File 'lib/aws-sdk-redshift/types.rb', line 9000

class ModifyCustomDomainAssociationMessage < Struct.new(
  :custom_domain_name,
  :custom_domain_certificate_arn,
  :cluster_identifier)
  SENSITIVE = []
  include Aws::Structure
end