Class: Aws::Redshift::Types::ModifyEventSubscriptionMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::ModifyEventSubscriptionMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
A Boolean value indicating if the subscription is enabled.
-
#event_categories ⇒ Array<String>
Specifies the Amazon Redshift event categories to be published by the event notification subscription.
-
#severity ⇒ String
Specifies the Amazon Redshift event severity to be published by the event notification subscription.
-
#sns_topic_arn ⇒ String
The Amazon Resource Name (ARN) of the SNS topic to be used by the event notification subscription.
-
#source_ids ⇒ Array<String>
A list of one or more identifiers of Amazon Redshift source objects.
-
#source_type ⇒ String
The type of source that will be generating the events.
-
#subscription_name ⇒ String
The name of the modified Amazon Redshift event notification subscription.
Instance Attribute Details
#enabled ⇒ Boolean
A Boolean value indicating if the subscription is enabled. true
indicates the subscription is enabled
9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 |
# File 'lib/aws-sdk-redshift/types.rb', line 9173 class ModifyEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :source_ids, :event_categories, :severity, :enabled) SENSITIVE = [] include Aws::Structure end |
#event_categories ⇒ Array<String>
Specifies the Amazon Redshift event categories to be published by the event notification subscription.
Values: configuration, management, monitoring, security, pending
9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 |
# File 'lib/aws-sdk-redshift/types.rb', line 9173 class ModifyEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :source_ids, :event_categories, :severity, :enabled) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
Specifies the Amazon Redshift event severity to be published by the event notification subscription.
Values: ERROR, INFO
9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 |
# File 'lib/aws-sdk-redshift/types.rb', line 9173 class ModifyEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :source_ids, :event_categories, :severity, :enabled) SENSITIVE = [] include Aws::Structure end |
#sns_topic_arn ⇒ String
The Amazon Resource Name (ARN) of the SNS topic to be used by the event notification subscription.
9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 |
# File 'lib/aws-sdk-redshift/types.rb', line 9173 class ModifyEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :source_ids, :event_categories, :severity, :enabled) SENSITIVE = [] include Aws::Structure end |
#source_ids ⇒ Array<String>
A list of one or more identifiers of Amazon Redshift source objects. All of the objects must be of the same type as was specified in the source type parameter. The event subscription will return only events generated by the specified objects. If not specified, then events are returned for all objects within the source type specified.
Example: my-cluster-1, my-cluster-2
Example: my-snapshot-20131010
9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 |
# File 'lib/aws-sdk-redshift/types.rb', line 9173 class ModifyEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :source_ids, :event_categories, :severity, :enabled) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The type of source that will be generating the events. For example, if you want to be notified of events generated by a cluster, you would set this parameter to cluster. If this value is not specified, events are returned for all Amazon Redshift objects in your Amazon Web Services account. You must specify a source type in order to specify source IDs.
Valid values: cluster, cluster-parameter-group, cluster-security-group, cluster-snapshot, and scheduled-action.
9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 |
# File 'lib/aws-sdk-redshift/types.rb', line 9173 class ModifyEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :source_ids, :event_categories, :severity, :enabled) SENSITIVE = [] include Aws::Structure end |
#subscription_name ⇒ String
The name of the modified Amazon Redshift event notification subscription.
9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 |
# File 'lib/aws-sdk-redshift/types.rb', line 9173 class ModifyEventSubscriptionMessage < Struct.new( :subscription_name, :sns_topic_arn, :source_type, :source_ids, :event_categories, :severity, :enabled) SENSITIVE = [] include Aws::Structure end |