Class: Aws::Redshift::Types::ModifyLakehouseConfigurationMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_nameString

The name of the Glue data catalog that will be associated with the cluster enabled with Amazon Redshift federated permissions.

Constraints:

  • Must contain at least one lowercase letter.

  • Can only contain lowercase letters (a-z), numbers (0-9), underscores (_), and hyphens (-).

Pattern: ‘^[a-z0-9_-]*+[a-z0-9_-]*$`

Example: my-catalog_01



9087
9088
9089
9090
9091
9092
9093
9094
9095
9096
# File 'lib/aws-sdk-redshift/types.rb', line 9087

class ModifyLakehouseConfigurationMessage < Struct.new(
  :cluster_identifier,
  :lakehouse_registration,
  :catalog_name,
  :lakehouse_idc_registration,
  :lakehouse_idc_application_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_identifierString

The unique identifier of the cluster whose lakehouse configuration you want to modify.



9087
9088
9089
9090
9091
9092
9093
9094
9095
9096
# File 'lib/aws-sdk-redshift/types.rb', line 9087

class ModifyLakehouseConfigurationMessage < Struct.new(
  :cluster_identifier,
  :lakehouse_registration,
  :catalog_name,
  :lakehouse_idc_registration,
  :lakehouse_idc_application_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

A boolean value that, if true, validates the request without actually modifying the lakehouse configuration. Use this to check for errors before making changes.



9087
9088
9089
9090
9091
9092
9093
9094
9095
9096
# File 'lib/aws-sdk-redshift/types.rb', line 9087

class ModifyLakehouseConfigurationMessage < Struct.new(
  :cluster_identifier,
  :lakehouse_registration,
  :catalog_name,
  :lakehouse_idc_registration,
  :lakehouse_idc_application_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#lakehouse_idc_application_arnString

The Amazon Resource Name (ARN) of the IAM Identity Center application used for enabling Amazon Web Services IAM Identity Center trusted identity propagation on a cluster enabled with Amazon Redshift federated permissions.



9087
9088
9089
9090
9091
9092
9093
9094
9095
9096
# File 'lib/aws-sdk-redshift/types.rb', line 9087

class ModifyLakehouseConfigurationMessage < Struct.new(
  :cluster_identifier,
  :lakehouse_registration,
  :catalog_name,
  :lakehouse_idc_registration,
  :lakehouse_idc_application_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#lakehouse_idc_registrationString

Modifies the Amazon Web Services IAM Identity Center trusted identity propagation on a cluster enabled with Amazon Redshift federated permissions. Valid values are Associate or Disassociate.



9087
9088
9089
9090
9091
9092
9093
9094
9095
9096
# File 'lib/aws-sdk-redshift/types.rb', line 9087

class ModifyLakehouseConfigurationMessage < Struct.new(
  :cluster_identifier,
  :lakehouse_registration,
  :catalog_name,
  :lakehouse_idc_registration,
  :lakehouse_idc_application_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#lakehouse_registrationString

Specifies whether to register or deregister the cluster with Amazon Redshift federated permissions. Valid values are Register or Deregister.



9087
9088
9089
9090
9091
9092
9093
9094
9095
9096
# File 'lib/aws-sdk-redshift/types.rb', line 9087

class ModifyLakehouseConfigurationMessage < Struct.new(
  :cluster_identifier,
  :lakehouse_registration,
  :catalog_name,
  :lakehouse_idc_registration,
  :lakehouse_idc_application_arn,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end