Class: Aws::Redshift::Types::ModifyQev2IdcApplicationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::ModifyQev2IdcApplicationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#idc_display_name ⇒ String
The display name for the Amazon Redshift Query Editor (QEV2) IAM Identity Center application.
-
#qev_2_idc_application_arn ⇒ String
The Amazon Resource Name (ARN) for the Amazon Redshift Query Editor (QEV2) application that integrates with IAM Identity Center.
Instance Attribute Details
#idc_display_name ⇒ String
The display name for the Amazon Redshift Query Editor (QEV2) IAM Identity Center application. It appears in the console.
9226 9227 9228 9229 9230 9231 |
# File 'lib/aws-sdk-redshift/types.rb', line 9226 class ModifyQev2IdcApplicationMessage < Struct.new( :qev_2_idc_application_arn, :idc_display_name) SENSITIVE = [] include Aws::Structure end |
#qev_2_idc_application_arn ⇒ String
The Amazon Resource Name (ARN) for the Amazon Redshift Query Editor (QEV2) application that integrates with IAM Identity Center.
9226 9227 9228 9229 9230 9231 |
# File 'lib/aws-sdk-redshift/types.rb', line 9226 class ModifyQev2IdcApplicationMessage < Struct.new( :qev_2_idc_application_arn, :idc_display_name) SENSITIVE = [] include Aws::Structure end |