Class: Aws::Redshift::Types::ModifyRedshiftIdcApplicationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::ModifyRedshiftIdcApplicationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorized_token_issuer_list ⇒ Array<Types::AuthorizedTokenIssuer>
The authorized token issuer list for the Amazon Redshift IAM Identity Center application to change.
-
#iam_role_arn ⇒ String
The IAM role ARN associated with the Amazon Redshift IAM Identity Center application to change.
-
#idc_display_name ⇒ String
The display name for the Amazon Redshift IAM Identity Center application to change.
-
#identity_namespace ⇒ String
The namespace for the Amazon Redshift IAM Identity Center application to change.
-
#redshift_idc_application_arn ⇒ String
The ARN for the Redshift application that integrates with IAM Identity Center.
-
#service_integrations ⇒ Array<Types::ServiceIntegrationsUnion>
A collection of service integrations associated with the application.
Instance Attribute Details
#authorized_token_issuer_list ⇒ Array<Types::AuthorizedTokenIssuer>
The authorized token issuer list for the Amazon Redshift IAM Identity Center application to change.
9346 9347 9348 9349 9350 9351 9352 9353 9354 9355 |
# File 'lib/aws-sdk-redshift/types.rb', line 9346 class ModifyRedshiftIdcApplicationMessage < Struct.new( :redshift_idc_application_arn, :identity_namespace, :iam_role_arn, :idc_display_name, :authorized_token_issuer_list, :service_integrations) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The IAM role ARN associated with the Amazon Redshift IAM Identity Center application to change. It has the required permissions to be assumed and invoke the IDC Identity Center API.
9346 9347 9348 9349 9350 9351 9352 9353 9354 9355 |
# File 'lib/aws-sdk-redshift/types.rb', line 9346 class ModifyRedshiftIdcApplicationMessage < Struct.new( :redshift_idc_application_arn, :identity_namespace, :iam_role_arn, :idc_display_name, :authorized_token_issuer_list, :service_integrations) SENSITIVE = [] include Aws::Structure end |
#idc_display_name ⇒ String
The display name for the Amazon Redshift IAM Identity Center application to change. It appears on the console.
9346 9347 9348 9349 9350 9351 9352 9353 9354 9355 |
# File 'lib/aws-sdk-redshift/types.rb', line 9346 class ModifyRedshiftIdcApplicationMessage < Struct.new( :redshift_idc_application_arn, :identity_namespace, :iam_role_arn, :idc_display_name, :authorized_token_issuer_list, :service_integrations) SENSITIVE = [] include Aws::Structure end |
#identity_namespace ⇒ String
The namespace for the Amazon Redshift IAM Identity Center application to change. It determines which managed application verifies the connection token.
9346 9347 9348 9349 9350 9351 9352 9353 9354 9355 |
# File 'lib/aws-sdk-redshift/types.rb', line 9346 class ModifyRedshiftIdcApplicationMessage < Struct.new( :redshift_idc_application_arn, :identity_namespace, :iam_role_arn, :idc_display_name, :authorized_token_issuer_list, :service_integrations) SENSITIVE = [] include Aws::Structure end |
#redshift_idc_application_arn ⇒ String
The ARN for the Redshift application that integrates with IAM Identity Center.
9346 9347 9348 9349 9350 9351 9352 9353 9354 9355 |
# File 'lib/aws-sdk-redshift/types.rb', line 9346 class ModifyRedshiftIdcApplicationMessage < Struct.new( :redshift_idc_application_arn, :identity_namespace, :iam_role_arn, :idc_display_name, :authorized_token_issuer_list, :service_integrations) SENSITIVE = [] include Aws::Structure end |
#service_integrations ⇒ Array<Types::ServiceIntegrationsUnion>
A collection of service integrations associated with the application.
9346 9347 9348 9349 9350 9351 9352 9353 9354 9355 |
# File 'lib/aws-sdk-redshift/types.rb', line 9346 class ModifyRedshiftIdcApplicationMessage < Struct.new( :redshift_idc_application_arn, :identity_namespace, :iam_role_arn, :idc_display_name, :authorized_token_issuer_list, :service_integrations) SENSITIVE = [] include Aws::Structure end |