Class: Aws::Redshift::Types::NodeConfigurationOptionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::NodeConfigurationOptionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#node_configuration_option_list ⇒ Array<Types::NodeConfigurationOption>
A list of valid node configurations.
Instance Attribute Details
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.
9132 9133 9134 9135 9136 9137 |
# File 'lib/aws-sdk-redshift/types.rb', line 9132 class NodeConfigurationOptionsMessage < Struct.new( :node_configuration_option_list, :marker) SENSITIVE = [] include Aws::Structure end |
#node_configuration_option_list ⇒ Array<Types::NodeConfigurationOption>
A list of valid node configurations.
9132 9133 9134 9135 9136 9137 |
# File 'lib/aws-sdk-redshift/types.rb', line 9132 class NodeConfigurationOptionsMessage < Struct.new( :node_configuration_option_list, :marker) SENSITIVE = [] include Aws::Structure end |