Class: Aws::Redshift::Types::Parameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::Parameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Describes a parameter in a cluster parameter group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_values ⇒ String
The valid range of values for the parameter.
-
#apply_type ⇒ String
Specifies how to apply the WLM configuration parameter.
-
#data_type ⇒ String
The data type of the parameter.
-
#description ⇒ String
A description of the parameter.
-
#is_modifiable ⇒ Boolean
If
true, the parameter can be modified. -
#minimum_engine_version ⇒ String
The earliest engine version to which the parameter can apply.
-
#parameter_name ⇒ String
The name of the parameter.
-
#parameter_value ⇒ String
The value of the parameter.
-
#source ⇒ String
The source of the parameter value, such as "engine-default" or "user".
Instance Attribute Details
#allowed_values ⇒ String
The valid range of values for the parameter.
9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 |
# File 'lib/aws-sdk-redshift/types.rb', line 9739 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :data_type, :allowed_values, :apply_type, :is_modifiable, :minimum_engine_version) SENSITIVE = [] include Aws::Structure end |
#apply_type ⇒ String
Specifies how to apply the WLM configuration parameter. Some properties can be applied dynamically, while other properties require that any associated clusters be rebooted for the configuration changes to be applied. For more information about parameters and parameter groups, go to Amazon Redshift Parameter Groups in the Amazon Redshift Cluster Management Guide.
9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 |
# File 'lib/aws-sdk-redshift/types.rb', line 9739 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :data_type, :allowed_values, :apply_type, :is_modifiable, :minimum_engine_version) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ String
The data type of the parameter.
9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 |
# File 'lib/aws-sdk-redshift/types.rb', line 9739 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :data_type, :allowed_values, :apply_type, :is_modifiable, :minimum_engine_version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the parameter.
9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 |
# File 'lib/aws-sdk-redshift/types.rb', line 9739 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :data_type, :allowed_values, :apply_type, :is_modifiable, :minimum_engine_version) SENSITIVE = [] include Aws::Structure end |
#is_modifiable ⇒ Boolean
If true, the parameter can be modified. Some parameters have
security or operational implications that prevent them from being
changed.
9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 |
# File 'lib/aws-sdk-redshift/types.rb', line 9739 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :data_type, :allowed_values, :apply_type, :is_modifiable, :minimum_engine_version) SENSITIVE = [] include Aws::Structure end |
#minimum_engine_version ⇒ String
The earliest engine version to which the parameter can apply.
9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 |
# File 'lib/aws-sdk-redshift/types.rb', line 9739 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :data_type, :allowed_values, :apply_type, :is_modifiable, :minimum_engine_version) SENSITIVE = [] include Aws::Structure end |
#parameter_name ⇒ String
The name of the parameter.
9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 |
# File 'lib/aws-sdk-redshift/types.rb', line 9739 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :data_type, :allowed_values, :apply_type, :is_modifiable, :minimum_engine_version) SENSITIVE = [] include Aws::Structure end |
#parameter_value ⇒ String
The value of the parameter. If ParameterName is
wlm_json_configuration, then the maximum size of ParameterValue
is 8000 characters.
9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 |
# File 'lib/aws-sdk-redshift/types.rb', line 9739 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :data_type, :allowed_values, :apply_type, :is_modifiable, :minimum_engine_version) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source of the parameter value, such as "engine-default" or "user".
9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 |
# File 'lib/aws-sdk-redshift/types.rb', line 9739 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :data_type, :allowed_values, :apply_type, :is_modifiable, :minimum_engine_version) SENSITIVE = [] include Aws::Structure end |