Class: Aws::Redshift::Types::PartnerIntegrationInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Describes a partner integration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date (UTC) that the partner integration was created.

Returns:

  • (Time)


9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-redshift/types.rb', line 9777

class PartnerIntegrationInfo < Struct.new(
  :database_name,
  :partner_name,
  :status,
  :status_message,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of the database that receives data from a partner.

Returns:

  • (String)


9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-redshift/types.rb', line 9777

class PartnerIntegrationInfo < Struct.new(
  :database_name,
  :partner_name,
  :status,
  :status_message,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#partner_nameString

The name of the partner.

Returns:

  • (String)


9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-redshift/types.rb', line 9777

class PartnerIntegrationInfo < Struct.new(
  :database_name,
  :partner_name,
  :status,
  :status_message,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The partner integration status.

Returns:

  • (String)


9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-redshift/types.rb', line 9777

class PartnerIntegrationInfo < Struct.new(
  :database_name,
  :partner_name,
  :status,
  :status_message,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

The status message provided by the partner.

Returns:

  • (String)


9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-redshift/types.rb', line 9777

class PartnerIntegrationInfo < Struct.new(
  :database_name,
  :partner_name,
  :status,
  :status_message,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date (UTC) that the partner integration status was last updated by the partner.

Returns:

  • (Time)


9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-redshift/types.rb', line 9777

class PartnerIntegrationInfo < Struct.new(
  :database_name,
  :partner_name,
  :status,
  :status_message,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end