Class: Aws::Redshift::Types::PendingModifiedValues

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Describes cluster attributes that are in a pending state. A change to one or more the attributes was requested and is in progress or will be applied.

Constant Summary collapse

SENSITIVE =
[:master_user_password]

Instance Attribute Summary collapse

Instance Attribute Details

#automated_snapshot_retention_periodInteger

The pending or in-progress change of the automated snapshot retention period.



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#cluster_identifierString

The pending or in-progress change of the new identifier for the cluster.



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#cluster_typeString

The pending or in-progress change of the cluster type.



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#cluster_versionString

The pending or in-progress change of the service version.



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#encryption_typeString

The encryption type for a cluster. Possible values are: KMS and None.



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#enhanced_vpc_routingBoolean

An option that specifies whether to create the cluster with enhanced VPC routing enabled. To create a cluster that uses enhanced VPC routing, the cluster must be in a VPC. For more information, see Enhanced VPC Routing in the Amazon Redshift Cluster Management Guide.

If this option is true, enhanced VPC routing is enabled.

Default: false



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#maintenance_track_nameString

The name of the maintenance track that the cluster will change to during the next maintenance window.



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#master_user_passwordString

The pending or in-progress change of the admin user password for the cluster.



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#node_typeString

The pending or in-progress change of the cluster's node type.



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#number_of_nodesInteger

The pending or in-progress change of the number of nodes in the cluster.



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#publicly_accessibleBoolean

The pending or in-progress change of the ability to connect to the cluster from the public network.



10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
# File 'lib/aws-sdk-redshift/types.rb', line 10000

class PendingModifiedValues < Struct.new(
  :master_user_password,
  :node_type,
  :number_of_nodes,
  :cluster_type,
  :cluster_version,
  :automated_snapshot_retention_period,
  :cluster_identifier,
  :publicly_accessible,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :encryption_type)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end