Class: Aws::Redshift::Types::Recommendation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

An Amazon Redshift Advisor recommended action on the Amazon Redshift cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

The unique identifier of the cluster for which the recommendation is returned.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time (UTC) that the recommendation was created.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the recommendation.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier of the Advisor recommendation.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

#impact_rankingString

The scale of the impact that the Advisor recommendation has to the performance and cost of the cluster.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

#namespace_arnString

The Amazon Redshift cluster namespace ARN for which the recommendations is returned.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

#observationString

The description of what was observed about your cluster.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_textString

The description of the recommendation.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

#recommendation_typeString

The type of Advisor recommendation.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

List of Amazon Redshift recommended actions.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

List of helpful links for more information about the Advisor recommendation.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the recommendation.



10259
10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
# File 'lib/aws-sdk-redshift/types.rb', line 10259

class Recommendation < Struct.new(
  :id,
  :cluster_identifier,
  :namespace_arn,
  :created_at,
  :recommendation_type,
  :title,
  :description,
  :observation,
  :impact_ranking,
  :recommendation_text,
  :recommended_actions,
  :reference_links)
  SENSITIVE = []
  include Aws::Structure
end