Class: Aws::Redshift::Types::RecurringCharge

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Describes a recurring charge.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#recurring_charge_amountFloat

The amount charged per the period of time specified by the recurring charge frequency.

Returns:

  • (Float)


10255
10256
10257
10258
10259
10260
# File 'lib/aws-sdk-redshift/types.rb', line 10255

class RecurringCharge < Struct.new(
  :recurring_charge_amount,
  :recurring_charge_frequency)
  SENSITIVE = []
  include Aws::Structure
end

#recurring_charge_frequencyString

The frequency at which the recurring charge amount is applied.

Returns:

  • (String)


10255
10256
10257
10258
10259
10260
# File 'lib/aws-sdk-redshift/types.rb', line 10255

class RecurringCharge < Struct.new(
  :recurring_charge_amount,
  :recurring_charge_frequency)
  SENSITIVE = []
  include Aws::Structure
end