Class: Aws::Redshift::Types::RedshiftScopeUnion
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::RedshiftScopeUnion
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Note:
RedshiftScopeUnion is a union - when making an API calls you must set exactly one of the members.
Note:
RedshiftScopeUnion is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RedshiftScopeUnion corresponding to the set member.
A union structure that defines the scope of Amazon Redshift service integrations. Contains configuration for different integration types such as Amazon Redshift.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connect ⇒ Types::Connect
The Amazon Redshift connect integration scope configuration.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#connect ⇒ Types::Connect
The Amazon Redshift connect integration scope configuration. Defines authorization settings for Amazon Redshift connect service integration.
10393 10394 10395 10396 10397 10398 10399 10400 10401 10402 |
# File 'lib/aws-sdk-redshift/types.rb', line 10393 class RedshiftScopeUnion < Struct.new( :connect, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Connect < RedshiftScopeUnion; end class Unknown < RedshiftScopeUnion; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10393 10394 10395 |
# File 'lib/aws-sdk-redshift/types.rb', line 10393 def unknown @unknown end |