Class: Aws::Redshift::Types::ReservedNodesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::ReservedNodesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#reserved_nodes ⇒ Array<Types::ReservedNode>
The list of
ReservedNodeobjects.
Instance Attribute Details
#marker ⇒ String
A value that indicates the starting point for the next set of
response records in a subsequent request. If a value is returned in
a response, you can retrieve the next set of records by providing
this returned marker value in the Marker parameter and retrying
the command. If the Marker field is empty, all response records
have been retrieved for the request.
10784 10785 10786 10787 10788 10789 |
# File 'lib/aws-sdk-redshift/types.rb', line 10784 class ReservedNodesMessage < Struct.new( :marker, :reserved_nodes) SENSITIVE = [] include Aws::Structure end |
#reserved_nodes ⇒ Array<Types::ReservedNode>
The list of ReservedNode objects.
10784 10785 10786 10787 10788 10789 |
# File 'lib/aws-sdk-redshift/types.rb', line 10784 class ReservedNodesMessage < Struct.new( :marker, :reserved_nodes) SENSITIVE = [] include Aws::Structure end |