Class: Aws::Redshift::Types::RevokeClusterSecurityGroupIngressMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::RevokeClusterSecurityGroupIngressMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidrip ⇒ String
The IP range for which to revoke access.
-
#cluster_security_group_name ⇒ String
The name of the security Group from which to revoke the ingress rule.
-
#ec2_security_group_name ⇒ String
The name of the EC2 Security Group whose access is to be revoked.
-
#ec2_security_group_owner_id ⇒ String
The Amazon Web Services account number of the owner of the security group specified in the
EC2SecurityGroupNameparameter.
Instance Attribute Details
#cidrip ⇒ String
The IP range for which to revoke access. This range must be a valid
Classless Inter-Domain Routing (CIDR) block of IP addresses. If
CIDRIP is specified, EC2SecurityGroupName and
EC2SecurityGroupOwnerId cannot be provided.
11661 11662 11663 11664 11665 11666 11667 11668 |
# File 'lib/aws-sdk-redshift/types.rb', line 11661 class RevokeClusterSecurityGroupIngressMessage < Struct.new( :cluster_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#cluster_security_group_name ⇒ String
The name of the security Group from which to revoke the ingress rule.
11661 11662 11663 11664 11665 11666 11667 11668 |
# File 'lib/aws-sdk-redshift/types.rb', line 11661 class RevokeClusterSecurityGroupIngressMessage < Struct.new( :cluster_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#ec2_security_group_name ⇒ String
The name of the EC2 Security Group whose access is to be revoked. If
EC2SecurityGroupName is specified, EC2SecurityGroupOwnerId must
also be provided and CIDRIP cannot be provided.
11661 11662 11663 11664 11665 11666 11667 11668 |
# File 'lib/aws-sdk-redshift/types.rb', line 11661 class RevokeClusterSecurityGroupIngressMessage < Struct.new( :cluster_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#ec2_security_group_owner_id ⇒ String
The Amazon Web Services account number of the owner of the security
group specified in the EC2SecurityGroupName parameter. The Amazon
Web Services access key ID is not an acceptable value. If
EC2SecurityGroupOwnerId is specified, EC2SecurityGroupName must
also be provided. and CIDRIP cannot be provided.
Example: 111122223333
11661 11662 11663 11664 11665 11666 11667 11668 |
# File 'lib/aws-sdk-redshift/types.rb', line 11661 class RevokeClusterSecurityGroupIngressMessage < Struct.new( :cluster_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |