Class: Aws::Redshift::Types::S3TablePublishStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Describes the status of system table publishing to S3 Tables for a cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabled_allBoolean

true if the cluster is enrolled in all current and future system tables rather than an explicit subset.



11898
11899
11900
11901
11902
11903
11904
11905
11906
# File 'lib/aws-sdk-redshift/types.rb', line 11898

class S3TablePublishStatus < Struct.new(
  :s3_tables,
  :s3_table_namespace,
  :s3_table_granularity,
  :enabled_all,
  :last_ingestion_times)
  SENSITIVE = []
  include Aws::Structure
end

#last_ingestion_timesHash<String,String>

A map whose keys are the names of the published system tables and whose values are the time each table last received data. Use this to judge data freshness.



11898
11899
11900
11901
11902
11903
11904
11905
11906
# File 'lib/aws-sdk-redshift/types.rb', line 11898

class S3TablePublishStatus < Struct.new(
  :s3_tables,
  :s3_table_namespace,
  :s3_table_granularity,
  :enabled_all,
  :last_ingestion_times)
  SENSITIVE = []
  include Aws::Structure
end

#s3_table_granularityString

The scope of system table publishing in effect. Possible values are cluster and account.



11898
11899
11900
11901
11902
11903
11904
11905
11906
# File 'lib/aws-sdk-redshift/types.rb', line 11898

class S3TablePublishStatus < Struct.new(
  :s3_tables,
  :s3_table_namespace,
  :s3_table_granularity,
  :enabled_all,
  :last_ingestion_times)
  SENSITIVE = []
  include Aws::Structure
end

#s3_table_namespaceString

The namespace in the S3 table bucket that holds the published tables.



11898
11899
11900
11901
11902
11903
11904
11905
11906
# File 'lib/aws-sdk-redshift/types.rb', line 11898

class S3TablePublishStatus < Struct.new(
  :s3_tables,
  :s3_table_namespace,
  :s3_table_granularity,
  :enabled_all,
  :last_ingestion_times)
  SENSITIVE = []
  include Aws::Structure
end

#s3_tablesArray<String>

The system tables currently being published.



11898
11899
11900
11901
11902
11903
11904
11905
11906
# File 'lib/aws-sdk-redshift/types.rb', line 11898

class S3TablePublishStatus < Struct.new(
  :s3_tables,
  :s3_table_namespace,
  :s3_table_granularity,
  :enabled_all,
  :last_ingestion_times)
  SENSITIVE = []
  include Aws::Structure
end