Class: Aws::Redshift::Types::Snapshot

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Describes a snapshot.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accounts_with_restore_accessArray<Types::AccountWithRestoreAccess>

A list of the Amazon Web Services accounts authorized to restore the snapshot. Returns null if no accounts are authorized. Visible only to the snapshot owner.



12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#actual_incremental_backup_size_in_mega_bytesFloat

The size of the incremental backup.

Returns:

  • (Float)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone in which the cluster was created.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#backup_progress_in_mega_bytesFloat

The number of megabytes that have been transferred to the snapshot backup.

Returns:

  • (Float)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_create_timeTime

The time (UTC) when the cluster was originally created.

Returns:

  • (Time)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_identifierString

The identifier of the cluster for which the snapshot was taken.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_versionString

The version ID of the Amazon Redshift engine that is running on the cluster.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#current_backup_rate_in_mega_bytes_per_secondFloat

The number of megabytes per second being transferred to the snapshot backup. Returns 0 for a completed backup.

Returns:

  • (Float)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#db_nameString

The name of the database that was created when the cluster was created.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#elapsed_time_in_secondsInteger

The amount of time an in-progress snapshot backup has been running, or the amount of time it took a completed backup to finish.

Returns:

  • (Integer)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#encryptedBoolean

If true, the data in the snapshot is encrypted at rest.

Returns:

  • (Boolean)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#encrypted_with_hsmBoolean

A boolean that indicates whether the snapshot data is encrypted using the HSM keys of the source cluster. true indicates that the data is encrypted using HSM keys.

Returns:

  • (Boolean)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#engine_full_versionString

The cluster version of the cluster used to create the snapshot. For example, 1.0.15503.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#enhanced_vpc_routingBoolean

An option that specifies whether to create the cluster with enhanced VPC routing enabled. To create a cluster that uses enhanced VPC routing, the cluster must be in a VPC. For more information, see Enhanced VPC Routing in the Amazon Redshift Cluster Management Guide.

If this option is true, enhanced VPC routing is enabled.

Default: false

Returns:

  • (Boolean)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_seconds_to_completionInteger

The estimate of the time remaining before the snapshot backup will complete. Returns 0 for a completed backup.

Returns:

  • (Integer)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Key Management Service (KMS) key ID of the encryption key that was used to encrypt data in the cluster from which the snapshot was taken.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_track_nameString

The name of the maintenance track for the snapshot.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#manual_snapshot_remaining_daysInteger

The number of days until a manual snapshot will pass its retention period.

Returns:

  • (Integer)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#manual_snapshot_retention_periodInteger

The number of days that a manual snapshot is retained. If the value is -1, the manual snapshot is retained indefinitely.

The value must be either -1 or an integer between 1 and 3,653.

Returns:

  • (Integer)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#master_password_secret_arnString

The Amazon Resource Name (ARN) for the cluster's admin user credentials secret.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#master_password_secret_kms_key_idString

The ID of the Key Management Service (KMS) key used to encrypt and store the cluster's admin credentials secret.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#master_usernameString

The admin user name for the cluster.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#node_typeString

The node type of the nodes in the cluster.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_nodesInteger

The number of nodes in the cluster.

Returns:

  • (Integer)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#owner_accountString

For manual snapshots, the Amazon Web Services account used to create or copy the snapshot. For automatic snapshots, the owner of the cluster. The owner can perform all snapshot actions, such as sharing a manual snapshot.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port that the cluster is listening on.

Returns:

  • (Integer)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#restorable_node_typesArray<String>

The list of node types that this cluster snapshot is able to restore into.

Returns:

  • (Array<String>)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_arnString

The Amazon Resource Name (ARN) of the snapshot.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_create_timeTime

The time (in UTC format) when Amazon Redshift began the snapshot. A snapshot contains a copy of the cluster data as of this exact time.

Returns:

  • (Time)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_identifierString

The snapshot identifier that is provided in the request.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_retention_start_timeTime

A timestamp representing the start of the retention period for the snapshot.

Returns:

  • (Time)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_typeString

The snapshot type. Snapshots created using CreateClusterSnapshot and CopyClusterSnapshot are of type "manual".

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#source_regionString

The source region from which the snapshot was copied.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The snapshot status. The value of the status depends on the API operation used:

  • CreateClusterSnapshot and CopyClusterSnapshot returns status as "creating".

  • DescribeClusterSnapshots returns status as "creating", "available", "final snapshot", or "failed".

  • DeleteClusterSnapshot returns status as "deleted".

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The list of tags for the cluster snapshot.

Returns:



12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#total_backup_size_in_mega_bytesFloat

The size of the complete set of backup data that would be used to restore the cluster.

Returns:

  • (Float)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The VPC identifier of the cluster if the snapshot is from a cluster in a VPC. Otherwise, this field is not in the output.

Returns:

  • (String)


12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
12426
12427
12428
12429
12430
12431
# File 'lib/aws-sdk-redshift/types.rb', line 12391

class Snapshot < Struct.new(
  :snapshot_identifier,
  :cluster_identifier,
  :snapshot_create_time,
  :status,
  :port,
  :availability_zone,
  :cluster_create_time,
  :master_username,
  :cluster_version,
  :engine_full_version,
  :snapshot_type,
  :node_type,
  :number_of_nodes,
  :db_name,
  :vpc_id,
  :encrypted,
  :kms_key_id,
  :encrypted_with_hsm,
  :accounts_with_restore_access,
  :owner_account,
  :total_backup_size_in_mega_bytes,
  :actual_incremental_backup_size_in_mega_bytes,
  :backup_progress_in_mega_bytes,
  :current_backup_rate_in_mega_bytes_per_second,
  :estimated_seconds_to_completion,
  :elapsed_time_in_seconds,
  :source_region,
  :tags,
  :restorable_node_types,
  :enhanced_vpc_routing,
  :maintenance_track_name,
  :manual_snapshot_retention_period,
  :manual_snapshot_remaining_days,
  :snapshot_retention_start_time,
  :master_password_secret_arn,
  :master_password_secret_kms_key_id,
  :snapshot_arn)
  SENSITIVE = []
  include Aws::Structure
end