Class: Aws::Redshift::Types::SnapshotCopyGrantMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::SnapshotCopyGrantMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records.
-
#snapshot_copy_grants ⇒ Array<Types::SnapshotCopyGrant>
The list of
SnapshotCopyGrantobjects.
Instance Attribute Details
#marker ⇒ String
An optional parameter that specifies the starting point to return a
set of response records. When the results of a
DescribeSnapshotCopyGrant request exceed the value specified in
MaxRecords, Amazon Web Services returns a value in the Marker
field of the response. You can retrieve the next set of response
records by providing the returned marker value in the Marker
parameter and retrying the request.
Constraints: You can specify either the SnapshotCopyGrantName parameter or the Marker parameter, but not both.
12408 12409 12410 12411 12412 12413 |
# File 'lib/aws-sdk-redshift/types.rb', line 12408 class SnapshotCopyGrantMessage < Struct.new( :marker, :snapshot_copy_grants) SENSITIVE = [] include Aws::Structure end |
#snapshot_copy_grants ⇒ Array<Types::SnapshotCopyGrant>
The list of SnapshotCopyGrant objects.
12408 12409 12410 12411 12412 12413 |
# File 'lib/aws-sdk-redshift/types.rb', line 12408 class SnapshotCopyGrantMessage < Struct.new( :marker, :snapshot_copy_grants) SENSITIVE = [] include Aws::Structure end |