Class: Aws::Redshift::Types::TableRestoreStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Describes the status of a RestoreTableFromClusterSnapshot operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

The identifier of the Amazon Redshift cluster that the table is being restored to.



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A description of the status of the table restore request. Status values include SUCCEEDED, FAILED, CANCELED, PENDING, IN_PROGRESS.



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#new_table_nameString

The name of the table to create as a result of the table restore request.



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#progress_in_mega_bytesInteger

The amount of data restored to the new table so far, in megabytes (MB).



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#request_timeTime

The time that the table restore request was made, in Universal Coordinated Time (UTC).



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_identifierString

The identifier of the snapshot that the table is being restored from.



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#source_database_nameString

The name of the source database that contains the table being restored.



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#source_schema_nameString

The name of the source schema that contains the table being restored.



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#source_table_nameString

The name of the source table being restored.



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

A value that describes the current state of the table restore request.

Valid Values: SUCCEEDED, FAILED, CANCELED, PENDING, IN_PROGRESS



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#table_restore_request_idString

The unique identifier for the table restore request.



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#target_database_nameString

The name of the database to restore the table to.



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#target_schema_nameString

The name of the schema to restore the table to.



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end

#total_data_in_mega_bytesInteger

The total amount of data to restore to the new table, in megabytes (MB).



12863
12864
12865
12866
12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/aws-sdk-redshift/types.rb', line 12863

class TableRestoreStatus < Struct.new(
  :table_restore_request_id,
  :status,
  :message,
  :request_time,
  :progress_in_mega_bytes,
  :total_data_in_mega_bytes,
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name)
  SENSITIVE = []
  include Aws::Structure
end