Class: Aws::Redshift::Types::TaggedResourceListMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::TaggedResourceListMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#tagged_resources ⇒ Array<Types::TaggedResource>
A list of tags with their associated resources.
Instance Attribute Details
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.
12669 12670 12671 12672 12673 12674 |
# File 'lib/aws-sdk-redshift/types.rb', line 12669 class TaggedResourceListMessage < Struct.new( :tagged_resources, :marker) SENSITIVE = [] include Aws::Structure end |
#tagged_resources ⇒ Array<Types::TaggedResource>
A list of tags with their associated resources.
12669 12670 12671 12672 12673 12674 |
# File 'lib/aws-sdk-redshift/types.rb', line 12669 class TaggedResourceListMessage < Struct.new( :tagged_resources, :marker) SENSITIVE = [] include Aws::Structure end |