Class: Aws::Redshift::Types::TrackListMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#maintenance_tracksArray<Types::MaintenanceTrack>

A list of maintenance tracks output by the DescribeClusterTracks operation.

Returns:



13014
13015
13016
13017
13018
13019
# File 'lib/aws-sdk-redshift/types.rb', line 13014

class TrackListMessage < Struct.new(
  :maintenance_tracks,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

The starting point to return a set of response tracklist records. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.

Returns:

  • (String)


13014
13015
13016
13017
13018
13019
# File 'lib/aws-sdk-redshift/types.rb', line 13014

class TrackListMessage < Struct.new(
  :maintenance_tracks,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end