Class: Aws::Redshift::Types::UsageLimitList
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::UsageLimitList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#usage_limits ⇒ Array<Types::UsageLimit>
Contains the output from the DescribeUsageLimits action.
Instance Attribute Details
#marker ⇒ String
A value that indicates the starting point for the next set of
response records in a subsequent request. If a value is returned in
a response, you can retrieve the next set of records by providing
this returned marker value in the Marker parameter and retrying
the command. If the Marker field is empty, all response records
have been retrieved for the request.
13195 13196 13197 13198 13199 13200 |
# File 'lib/aws-sdk-redshift/types.rb', line 13195 class UsageLimitList < Struct.new( :usage_limits, :marker) SENSITIVE = [] include Aws::Structure end |
#usage_limits ⇒ Array<Types::UsageLimit>
Contains the output from the DescribeUsageLimits action.
13195 13196 13197 13198 13199 13200 |
# File 'lib/aws-sdk-redshift/types.rb', line 13195 class UsageLimitList < Struct.new( :usage_limits, :marker) SENSITIVE = [] include Aws::Structure end |