Class: Aws::Redshift::Types::CreateHsmConfigurationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::CreateHsmConfigurationResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hsm_configuration ⇒ Types::HsmConfiguration
Returns information about an HSM configuration, which is an object that describes to Amazon Redshift clusters the information they require to connect to an HSM where they can store database encryption keys.
Instance Attribute Details
#hsm_configuration ⇒ Types::HsmConfiguration
Returns information about an HSM configuration, which is an object that describes to Amazon Redshift clusters the information they require to connect to an HSM where they can store database encryption keys.
2966 2967 2968 2969 2970 |
# File 'lib/aws-sdk-redshift/types.rb', line 2966 class CreateHsmConfigurationResult < Struct.new( :hsm_configuration) SENSITIVE = [] include Aws::Structure end |