Class: Aws::Redshift::Types::CreateUsageLimitMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::CreateUsageLimitMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The limit amount.
-
#breach_action ⇒ String
The action that Amazon Redshift takes when the limit is reached.
-
#cluster_identifier ⇒ String
The identifier of the cluster that you want to limit usage.
-
#feature_type ⇒ String
The Amazon Redshift feature that you want to limit.
-
#limit_type ⇒ String
The type of limit.
-
#period ⇒ String
The time period that the amount applies to.
-
#tags ⇒ Array<Types::Tag>
A list of tag instances.
Instance Attribute Details
#amount ⇒ Integer
The limit amount. If time-based, this amount is in minutes. If data-based, this amount is in terabytes (TB). The value must be a positive number.
3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 |
# File 'lib/aws-sdk-redshift/types.rb', line 3383 class CreateUsageLimitMessage < Struct.new( :cluster_identifier, :feature_type, :limit_type, :amount, :period, :breach_action, :tags) SENSITIVE = [] include Aws::Structure end |
#breach_action ⇒ String
The action that Amazon Redshift takes when the limit is reached. The default is log. For more information about this parameter, see UsageLimit.
3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 |
# File 'lib/aws-sdk-redshift/types.rb', line 3383 class CreateUsageLimitMessage < Struct.new( :cluster_identifier, :feature_type, :limit_type, :amount, :period, :breach_action, :tags) SENSITIVE = [] include Aws::Structure end |
#cluster_identifier ⇒ String
The identifier of the cluster that you want to limit usage.
3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 |
# File 'lib/aws-sdk-redshift/types.rb', line 3383 class CreateUsageLimitMessage < Struct.new( :cluster_identifier, :feature_type, :limit_type, :amount, :period, :breach_action, :tags) SENSITIVE = [] include Aws::Structure end |
#feature_type ⇒ String
The Amazon Redshift feature that you want to limit.
3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 |
# File 'lib/aws-sdk-redshift/types.rb', line 3383 class CreateUsageLimitMessage < Struct.new( :cluster_identifier, :feature_type, :limit_type, :amount, :period, :breach_action, :tags) SENSITIVE = [] include Aws::Structure end |
#limit_type ⇒ String
The type of limit. Depending on the feature type, this can be based
on a time duration or data size. If FeatureType is spectrum,
then LimitType must be data-scanned. If FeatureType is
concurrency-scaling, then LimitType must be time. If
FeatureType is cross-region-datasharing, then LimitType must
be data-scanned. If FeatureType is
extra-compute-for-automatic-optimization, then LimitType must be
time.
3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 |
# File 'lib/aws-sdk-redshift/types.rb', line 3383 class CreateUsageLimitMessage < Struct.new( :cluster_identifier, :feature_type, :limit_type, :amount, :period, :breach_action, :tags) SENSITIVE = [] include Aws::Structure end |
#period ⇒ String
The time period that the amount applies to. A weekly period begins
on Sunday. The default is monthly.
3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 |
# File 'lib/aws-sdk-redshift/types.rb', line 3383 class CreateUsageLimitMessage < Struct.new( :cluster_identifier, :feature_type, :limit_type, :amount, :period, :breach_action, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tag instances.
3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 |
# File 'lib/aws-sdk-redshift/types.rb', line 3383 class CreateUsageLimitMessage < Struct.new( :cluster_identifier, :feature_type, :limit_type, :amount, :period, :breach_action, :tags) SENSITIVE = [] include Aws::Structure end |