Class: Aws::Redshift::Types::DefaultClusterParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Describes the default cluster parameters for a parameter group family.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


3470
3471
3472
3473
3474
3475
3476
# File 'lib/aws-sdk-redshift/types.rb', line 3470

class DefaultClusterParameters < Struct.new(
  :parameter_group_family,
  :marker,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_group_familyString

The name of the cluster parameter group family to which the engine default parameters apply.

Returns:

  • (String)


3470
3471
3472
3473
3474
3475
3476
# File 'lib/aws-sdk-redshift/types.rb', line 3470

class DefaultClusterParameters < Struct.new(
  :parameter_group_family,
  :marker,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersArray<Types::Parameter>

The list of cluster default parameters.

Returns:



3470
3471
3472
3473
3474
3475
3476
# File 'lib/aws-sdk-redshift/types.rb', line 3470

class DefaultClusterParameters < Struct.new(
  :parameter_group_family,
  :marker,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end