Class: Aws::Redshift::Types::DefaultClusterParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DefaultClusterParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Describes the default cluster parameters for a parameter group family.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#parameter_group_family ⇒ String
The name of the cluster parameter group family to which the engine default parameters apply.
-
#parameters ⇒ Array<Types::Parameter>
The list of cluster default parameters.
Instance Attribute Details
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.
3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-redshift/types.rb', line 3470 class DefaultClusterParameters < Struct.new( :parameter_group_family, :marker, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameter_group_family ⇒ String
The name of the cluster parameter group family to which the engine default parameters apply.
3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-redshift/types.rb', line 3470 class DefaultClusterParameters < Struct.new( :parameter_group_family, :marker, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::Parameter>
The list of cluster default parameters.
3470 3471 3472 3473 3474 3475 3476 |
# File 'lib/aws-sdk-redshift/types.rb', line 3470 class DefaultClusterParameters < Struct.new( :parameter_group_family, :marker, :parameters) SENSITIVE = [] include Aws::Structure end |