Class: Aws::Redshift::Types::DescribeClusterDbRevisionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeClusterDbRevisionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_identifier ⇒ String
A unique identifier for a cluster whose
ClusterDbRevisionsyou are requesting. -
#marker ⇒ String
An optional parameter that specifies the starting point for returning a set of response records.
-
#max_records ⇒ Integer
The maximum number of response records to return in each call.
Instance Attribute Details
#cluster_identifier ⇒ String
A unique identifier for a cluster whose ClusterDbRevisions you are requesting. This parameter is case sensitive. All clusters defined for an account are returned by default.
3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-redshift/types.rb', line 3950 class DescribeClusterDbRevisionsMessage < Struct.new( :cluster_identifier, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional parameter that specifies the starting point for returning a set of response records. When the results of a DescribeClusterDbRevisions request exceed the value specified in MaxRecords, Amazon Redshift returns a value in the marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the marker parameter and retrying the request.
Constraints: You can specify either the ClusterIdentifier parameter, or the marker parameter, but not both.
3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-redshift/types.rb', line 3950 class DescribeClusterDbRevisionsMessage < Struct.new( :cluster_identifier, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in the marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the marker parameter and retrying the request.
Default: 100
Constraints: minimum 20, maximum 100.
3950 3951 3952 3953 3954 3955 3956 |
# File 'lib/aws-sdk-redshift/types.rb', line 3950 class DescribeClusterDbRevisionsMessage < Struct.new( :cluster_identifier, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |