Class: Aws::Redshift::Types::DescribeClusterParametersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeClusterParametersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records.
-
#max_records ⇒ Integer
The maximum number of response records to return in each call.
-
#parameter_group_name ⇒ String
The name of a cluster parameter group for which to return details.
-
#source ⇒ String
The parameter types to return.
Instance Attribute Details
#marker ⇒ String
An optional parameter that specifies the starting point to return a
set of response records. When the results of a
DescribeClusterParameters request exceed the value specified in
MaxRecords, Amazon Web Services returns a value in the Marker
field of the response. You can retrieve the next set of response
records by providing the returned marker value in the Marker
parameter and retrying the request.
4242 4243 4244 4245 4246 4247 4248 4249 |
# File 'lib/aws-sdk-redshift/types.rb', line 4242 class DescribeClusterParametersMessage < Struct.new( :parameter_group_name, :source, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of response records to return in each call. If
the number of remaining response records exceeds the specified
MaxRecords value, a value is returned in a marker field of the
response. You can retrieve the next set of records by retrying the
command with the returned marker value.
Default: 100
Constraints: minimum 20, maximum 100.
4242 4243 4244 4245 4246 4247 4248 4249 |
# File 'lib/aws-sdk-redshift/types.rb', line 4242 class DescribeClusterParametersMessage < Struct.new( :parameter_group_name, :source, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#parameter_group_name ⇒ String
The name of a cluster parameter group for which to return details.
4242 4243 4244 4245 4246 4247 4248 4249 |
# File 'lib/aws-sdk-redshift/types.rb', line 4242 class DescribeClusterParametersMessage < Struct.new( :parameter_group_name, :source, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The parameter types to return. Specify user to show parameters
that are different form the default. Similarly, specify
engine-default to show parameters that are the same as the default
parameter group.
Default: All parameter types returned.
Valid Values: user | engine-default
4242 4243 4244 4245 4246 4247 4248 4249 |
# File 'lib/aws-sdk-redshift/types.rb', line 4242 class DescribeClusterParametersMessage < Struct.new( :parameter_group_name, :source, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |