Class: Aws::Redshift::Types::DescribeDataSharesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_sharesArray<Types::DataShare>

The results returned from describing datashares.

Returns:



4871
4872
4873
4874
4875
4876
# File 'lib/aws-sdk-redshift/types.rb', line 4871

class DescribeDataSharesResult < Struct.new(
  :data_shares,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeDataShares request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.

Returns:

  • (String)


4871
4872
4873
4874
4875
4876
# File 'lib/aws-sdk-redshift/types.rb', line 4871

class DescribeDataSharesResult < Struct.new(
  :data_shares,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end