Class: Aws::Redshift::Types::DescribeDataSharesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeDataSharesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_shares ⇒ Array<Types::DataShare>
The results returned from describing datashares.
-
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records.
Instance Attribute Details
#data_shares ⇒ Array<Types::DataShare>
The results returned from describing datashares.
4680 4681 4682 4683 4684 4685 |
# File 'lib/aws-sdk-redshift/types.rb', line 4680 class DescribeDataSharesResult < Struct.new( :data_shares, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeDataShares request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.
4680 4681 4682 4683 4684 4685 |
# File 'lib/aws-sdk-redshift/types.rb', line 4680 class DescribeDataSharesResult < Struct.new( :data_shares, :marker) SENSITIVE = [] include Aws::Structure end |