Class: Aws::Redshift::Types::DescribeEndpointAccessMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeEndpointAccessMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_identifier ⇒ String
The cluster identifier associated with the described endpoint.
-
#endpoint_name ⇒ String
The name of the endpoint to be described.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeEndpointAccessrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#resource_owner ⇒ String
The Amazon Web Services account ID of the owner of the cluster.
-
#vpc_id ⇒ String
The virtual private cloud (VPC) identifier with access to the cluster.
Instance Attribute Details
#cluster_identifier ⇒ String
The cluster identifier associated with the described endpoint.
4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 |
# File 'lib/aws-sdk-redshift/types.rb', line 4769 class DescribeEndpointAccessMessage < Struct.new( :cluster_identifier, :resource_owner, :endpoint_name, :vpc_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#endpoint_name ⇒ String
The name of the endpoint to be described.
4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 |
# File 'lib/aws-sdk-redshift/types.rb', line 4769 class DescribeEndpointAccessMessage < Struct.new( :cluster_identifier, :resource_owner, :endpoint_name, :vpc_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeEndpointAccess request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by the MaxRecords parameter.
4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 |
# File 'lib/aws-sdk-redshift/types.rb', line 4769 class DescribeEndpointAccessMessage < Struct.new( :cluster_identifier, :resource_owner, :endpoint_name, :vpc_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a Marker is included in the response so that the remaining results can be retrieved.
4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 |
# File 'lib/aws-sdk-redshift/types.rb', line 4769 class DescribeEndpointAccessMessage < Struct.new( :cluster_identifier, :resource_owner, :endpoint_name, :vpc_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#resource_owner ⇒ String
The Amazon Web Services account ID of the owner of the cluster.
4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 |
# File 'lib/aws-sdk-redshift/types.rb', line 4769 class DescribeEndpointAccessMessage < Struct.new( :cluster_identifier, :resource_owner, :endpoint_name, :vpc_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The virtual private cloud (VPC) identifier with access to the cluster.
4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 |
# File 'lib/aws-sdk-redshift/types.rb', line 4769 class DescribeEndpointAccessMessage < Struct.new( :cluster_identifier, :resource_owner, :endpoint_name, :vpc_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |