Class: Aws::Redshift::Types::DescribeEndpointAuthorizationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeEndpointAuthorizationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account ⇒ String
The Amazon Web Services account ID of either the cluster owner (grantor) or grantee.
-
#cluster_identifier ⇒ String
The cluster identifier of the cluster to access.
-
#grantee ⇒ Boolean
Indicates whether to check authorization from a grantor or grantee point of view.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeEndpointAuthorizationrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#account ⇒ String
The Amazon Web Services account ID of either the cluster owner
(grantor) or grantee. If Grantee parameter is true, then the
Account value is of the grantor.
4939 4940 4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-redshift/types.rb', line 4939 class DescribeEndpointAuthorizationMessage < Struct.new( :cluster_identifier, :account, :grantee, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#cluster_identifier ⇒ String
The cluster identifier of the cluster to access.
4939 4940 4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-redshift/types.rb', line 4939 class DescribeEndpointAuthorizationMessage < Struct.new( :cluster_identifier, :account, :grantee, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#grantee ⇒ Boolean
Indicates whether to check authorization from a grantor or grantee point of view. If true, Amazon Redshift returns endpoint authorizations that you've been granted. If false (default), checks authorization from a grantor point of view.
4939 4940 4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-redshift/types.rb', line 4939 class DescribeEndpointAuthorizationMessage < Struct.new( :cluster_identifier, :account, :grantee, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeEndpointAuthorization request. If this parameter is
specified, the response includes only records beyond the marker, up
to the value specified by the MaxRecords parameter.
4939 4940 4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-redshift/types.rb', line 4939 class DescribeEndpointAuthorizationMessage < Struct.new( :cluster_identifier, :account, :grantee, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a Marker is included in the response so that the
remaining results can be retrieved.
4939 4940 4941 4942 4943 4944 4945 4946 4947 |
# File 'lib/aws-sdk-redshift/types.rb', line 4939 class DescribeEndpointAuthorizationMessage < Struct.new( :cluster_identifier, :account, :grantee, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |