Class: Aws::Redshift::Types::DescribeIntegrationsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeIntegrationsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::DescribeIntegrationsFilter>
A filter that specifies one or more resources to return.
-
#integration_arn ⇒ String
The unique identifier of the integration.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeIntegrationsrequest. -
#max_records ⇒ Integer
The maximum number of response records to return in each call.
Instance Attribute Details
#filters ⇒ Array<Types::DescribeIntegrationsFilter>
A filter that specifies one or more resources to return.
5222 5223 5224 5225 5226 5227 5228 5229 |
# File 'lib/aws-sdk-redshift/types.rb', line 5222 class DescribeIntegrationsMessage < Struct.new( :integration_arn, :max_records, :marker, :filters) SENSITIVE = [] include Aws::Structure end |
#integration_arn ⇒ String
The unique identifier of the integration.
5222 5223 5224 5225 5226 5227 5228 5229 |
# File 'lib/aws-sdk-redshift/types.rb', line 5222 class DescribeIntegrationsMessage < Struct.new( :integration_arn, :max_records, :marker, :filters) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeIntegrations request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
5222 5223 5224 5225 5226 5227 5228 5229 |
# File 'lib/aws-sdk-redshift/types.rb', line 5222 class DescribeIntegrationsMessage < Struct.new( :integration_arn, :max_records, :marker, :filters) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.
Default: 100
Constraints: minimum 20, maximum 100.
5222 5223 5224 5225 5226 5227 5228 5229 |
# File 'lib/aws-sdk-redshift/types.rb', line 5222 class DescribeIntegrationsMessage < Struct.new( :integration_arn, :max_records, :marker, :filters) SENSITIVE = [] include Aws::Structure end |