Class: Aws::Redshift::Types::DescribeQev2IdcApplicationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeQev2IdcApplicationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#qev_2_idc_applications ⇒ Array<Types::Qev2IdcApplication>
The list of Amazon Redshift Query Editor (QEV2) IAM Identity Center applications.
Instance Attribute Details
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.
5646 5647 5648 5649 5650 5651 |
# File 'lib/aws-sdk-redshift/types.rb', line 5646 class DescribeQev2IdcApplicationsResult < Struct.new( :qev_2_idc_applications, :marker) SENSITIVE = [] include Aws::Structure end |
#qev_2_idc_applications ⇒ Array<Types::Qev2IdcApplication>
The list of Amazon Redshift Query Editor (QEV2) IAM Identity Center applications.
5646 5647 5648 5649 5650 5651 |
# File 'lib/aws-sdk-redshift/types.rb', line 5646 class DescribeQev2IdcApplicationsResult < Struct.new( :qev_2_idc_applications, :marker) SENSITIVE = [] include Aws::Structure end |