Class: Aws::Redshift::Types::DescribeTableRestoreStatusMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::DescribeTableRestoreStatusMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_identifier ⇒ String
The Amazon Redshift cluster that the table is being restored to.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeTableRestoreStatusrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#table_restore_request_id ⇒ String
The identifier of the table restore request to return status for.
Instance Attribute Details
#cluster_identifier ⇒ String
The Amazon Redshift cluster that the table is being restored to.
6070 6071 6072 6073 6074 6075 6076 6077 |
# File 'lib/aws-sdk-redshift/types.rb', line 6070 class DescribeTableRestoreStatusMessage < Struct.new( :cluster_identifier, :table_restore_request_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeTableRestoreStatus request. If this parameter is
specified, the response includes only records beyond the marker, up
to the value specified by the MaxRecords parameter.
6070 6071 6072 6073 6074 6075 6076 6077 |
# File 'lib/aws-sdk-redshift/types.rb', line 6070 class DescribeTableRestoreStatusMessage < Struct.new( :cluster_identifier, :table_restore_request_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that the
remaining results can be retrieved.
6070 6071 6072 6073 6074 6075 6076 6077 |
# File 'lib/aws-sdk-redshift/types.rb', line 6070 class DescribeTableRestoreStatusMessage < Struct.new( :cluster_identifier, :table_restore_request_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#table_restore_request_id ⇒ String
The identifier of the table restore request to return status for. If
you don't specify a TableRestoreRequestId value, then
DescribeTableRestoreStatus returns the status of all in-progress
table restore requests.
6070 6071 6072 6073 6074 6075 6076 6077 |
# File 'lib/aws-sdk-redshift/types.rb', line 6070 class DescribeTableRestoreStatusMessage < Struct.new( :cluster_identifier, :table_restore_request_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |