Class: Aws::Redshift::Types::DescribeTableRestoreStatusMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

The Amazon Redshift cluster that the table is being restored to.



5830
5831
5832
5833
5834
5835
5836
5837
# File 'lib/aws-sdk-redshift/types.rb', line 5830

class DescribeTableRestoreStatusMessage < Struct.new(
  :cluster_identifier,
  :table_restore_request_id,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DescribeTableRestoreStatus request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by the MaxRecords parameter.



5830
5831
5832
5833
5834
5835
5836
5837
# File 'lib/aws-sdk-redshift/types.rb', line 5830

class DescribeTableRestoreStatusMessage < Struct.new(
  :cluster_identifier,
  :table_restore_request_id,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.



5830
5831
5832
5833
5834
5835
5836
5837
# File 'lib/aws-sdk-redshift/types.rb', line 5830

class DescribeTableRestoreStatusMessage < Struct.new(
  :cluster_identifier,
  :table_restore_request_id,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#table_restore_request_idString

The identifier of the table restore request to return status for. If you don’t specify a TableRestoreRequestId value, then DescribeTableRestoreStatus returns the status of all in-progress table restore requests.



5830
5831
5832
5833
5834
5835
5836
5837
# File 'lib/aws-sdk-redshift/types.rb', line 5830

class DescribeTableRestoreStatusMessage < Struct.new(
  :cluster_identifier,
  :table_restore_request_id,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end