Class: Aws::Redshift::Types::EventsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::EventsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events ⇒ Array<Types::Event>
A list of
Eventinstances. -
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
Instance Attribute Details
#events ⇒ Array<Types::Event>
A list of Event instances.
6721 6722 6723 6724 6725 6726 |
# File 'lib/aws-sdk-redshift/types.rb', line 6721 class EventsMessage < Struct.new( :marker, :events) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.
6721 6722 6723 6724 6725 6726 |
# File 'lib/aws-sdk-redshift/types.rb', line 6721 class EventsMessage < Struct.new( :marker, :events) SENSITIVE = [] include Aws::Structure end |