Class: Aws::Redshift::Types::GetClusterCredentialsWithIAMMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::GetClusterCredentialsWithIAMMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_identifier ⇒ String
The unique identifier of the cluster that contains the database for which you are requesting credentials.
-
#custom_domain_name ⇒ String
The custom domain name for the IAM message cluster credentials.
-
#db_name ⇒ String
The name of the database for which you are requesting credentials.
-
#duration_seconds ⇒ Integer
The number of seconds until the returned temporary password expires.
Instance Attribute Details
#cluster_identifier ⇒ String
The unique identifier of the cluster that contains the database for which you are requesting credentials.
6902 6903 6904 6905 6906 6907 6908 6909 |
# File 'lib/aws-sdk-redshift/types.rb', line 6902 class GetClusterCredentialsWithIAMMessage < Struct.new( :db_name, :cluster_identifier, :duration_seconds, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#custom_domain_name ⇒ String
The custom domain name for the IAM message cluster credentials.
6902 6903 6904 6905 6906 6907 6908 6909 |
# File 'lib/aws-sdk-redshift/types.rb', line 6902 class GetClusterCredentialsWithIAMMessage < Struct.new( :db_name, :cluster_identifier, :duration_seconds, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#db_name ⇒ String
The name of the database for which you are requesting credentials. If the database name is specified, the IAM policy must allow access to the resource dbname for the specified database name. If the database name is not specified, access to all databases is allowed.
6902 6903 6904 6905 6906 6907 6908 6909 |
# File 'lib/aws-sdk-redshift/types.rb', line 6902 class GetClusterCredentialsWithIAMMessage < Struct.new( :db_name, :cluster_identifier, :duration_seconds, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |
#duration_seconds ⇒ Integer
The number of seconds until the returned temporary password expires.
Range: 900-3600. Default: 900.
6902 6903 6904 6905 6906 6907 6908 6909 |
# File 'lib/aws-sdk-redshift/types.rb', line 6902 class GetClusterCredentialsWithIAMMessage < Struct.new( :db_name, :cluster_identifier, :duration_seconds, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |