Method: Aws::Redshift::Types::GetClusterCredentialsWithIAMMessage#db_name
- Defined in:
- lib/aws-sdk-redshift/types.rb
#db_name ⇒ String
The name of the database for which you are requesting credentials. If the database name is specified, the IAM policy must allow access to the resource dbname for the specified database name. If the database name is not specified, access to all databases is allowed.
7027 7028 7029 7030 7031 7032 7033 7034 |
# File 'lib/aws-sdk-redshift/types.rb', line 7027 class GetClusterCredentialsWithIAMMessage < Struct.new( :db_name, :cluster_identifier, :duration_seconds, :custom_domain_name) SENSITIVE = [] include Aws::Structure end |