Class: Aws::Redshift::Types::GetReservedNodeExchangeConfigurationOptionsOutputMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::GetReservedNodeExchangeConfigurationOptionsOutputMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A pagination token provided by a previous
GetReservedNodeExchangeConfigurationOptionsrequest. -
#reserved_node_configuration_option_list ⇒ Array<Types::ReservedNodeConfigurationOption>
the configuration options for the reserved-node exchange.
Instance Attribute Details
#marker ⇒ String
A pagination token provided by a previous
GetReservedNodeExchangeConfigurationOptions request.
7270 7271 7272 7273 7274 7275 |
# File 'lib/aws-sdk-redshift/types.rb', line 7270 class GetReservedNodeExchangeConfigurationOptionsOutputMessage < Struct.new( :marker, :reserved_node_configuration_option_list) SENSITIVE = [] include Aws::Structure end |
#reserved_node_configuration_option_list ⇒ Array<Types::ReservedNodeConfigurationOption>
the configuration options for the reserved-node exchange. These options include information about the source reserved node and target reserved node. Details include the node type, the price, the node count, and the offering type.
7270 7271 7272 7273 7274 7275 |
# File 'lib/aws-sdk-redshift/types.rb', line 7270 class GetReservedNodeExchangeConfigurationOptionsOutputMessage < Struct.new( :marker, :reserved_node_configuration_option_list) SENSITIVE = [] include Aws::Structure end |