Class: Aws::Redshift::Types::HsmClientCertificate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::HsmClientCertificate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Returns information about an HSM client certificate. The certificate is stored in a secure Hardware Storage Module (HSM), and used by the Amazon Redshift cluster to encrypt data files.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hsm_client_certificate_identifier ⇒ String
The identifier of the HSM client certificate.
-
#hsm_client_certificate_public_key ⇒ String
The public key that the Amazon Redshift cluster will use to connect to the HSM.
-
#tags ⇒ Array<Types::Tag>
The list of tags for the HSM client certificate.
Instance Attribute Details
#hsm_client_certificate_identifier ⇒ String
The identifier of the HSM client certificate.
7411 7412 7413 7414 7415 7416 7417 |
# File 'lib/aws-sdk-redshift/types.rb', line 7411 class HsmClientCertificate < Struct.new( :hsm_client_certificate_identifier, :hsm_client_certificate_public_key, :tags) SENSITIVE = [] include Aws::Structure end |
#hsm_client_certificate_public_key ⇒ String
The public key that the Amazon Redshift cluster will use to connect to the HSM. You must register the public key in the HSM.
7411 7412 7413 7414 7415 7416 7417 |
# File 'lib/aws-sdk-redshift/types.rb', line 7411 class HsmClientCertificate < Struct.new( :hsm_client_certificate_identifier, :hsm_client_certificate_public_key, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The list of tags for the HSM client certificate.
7411 7412 7413 7414 7415 7416 7417 |
# File 'lib/aws-sdk-redshift/types.rb', line 7411 class HsmClientCertificate < Struct.new( :hsm_client_certificate_identifier, :hsm_client_certificate_public_key, :tags) SENSITIVE = [] include Aws::Structure end |