Class: Aws::Redshift::Types::HsmConfigurationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::HsmConfigurationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hsm_configurations ⇒ Array<Types::HsmConfiguration>
A list of
HsmConfigurationobjects. -
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
Instance Attribute Details
#hsm_configurations ⇒ Array<Types::HsmConfiguration>
A list of HsmConfiguration objects.
7188 7189 7190 7191 7192 7193 |
# File 'lib/aws-sdk-redshift/types.rb', line 7188 class HsmConfigurationMessage < Struct.new( :marker, :hsm_configurations) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.
7188 7189 7190 7191 7192 7193 |
# File 'lib/aws-sdk-redshift/types.rb', line 7188 class HsmConfigurationMessage < Struct.new( :marker, :hsm_configurations) SENSITIVE = [] include Aws::Structure end |