Class: Aws::Redshift::Types::IntegrationsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#integrationsArray<Types::Integration>

List of integrations that are described.

Returns:



7812
7813
7814
7815
7816
7817
# File 'lib/aws-sdk-redshift/types.rb', line 7812

class IntegrationsMessage < Struct.new(
  :marker,
  :integrations)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


7812
7813
7814
7815
7816
7817
# File 'lib/aws-sdk-redshift/types.rb', line 7812

class IntegrationsMessage < Struct.new(
  :marker,
  :integrations)
  SENSITIVE = []
  include Aws::Structure
end