Class: Aws::Redshift::Types::LoggingStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::LoggingStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Describes the status of logging for a cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
The name of the S3 bucket where the log files are stored.
-
#last_failure_message ⇒ String
The message indicating that logs failed to be delivered.
-
#last_failure_time ⇒ Time
The last time when logs failed to be delivered.
-
#last_successful_delivery_time ⇒ Time
The last time that logs were delivered.
-
#log_destination_type ⇒ String
The log destination type.
-
#log_exports ⇒ Array<String>
The collection of exported log types.
-
#logging_enabled ⇒ Boolean
trueif logging is on,falseif logging is off. -
#s3_key_prefix ⇒ String
The prefix applied to the log file names.
-
#s3_tables ⇒ Types::S3TablePublishStatus
The status of system table publishing to S3 Tables.
Instance Attribute Details
#bucket_name ⇒ String
The name of the S3 bucket where the log files are stored.
8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 |
# File 'lib/aws-sdk-redshift/types.rb', line 8287 class LoggingStatus < Struct.new( :logging_enabled, :bucket_name, :s3_key_prefix, :last_successful_delivery_time, :last_failure_time, :last_failure_message, :log_destination_type, :log_exports, :s3_tables) SENSITIVE = [] include Aws::Structure end |
#last_failure_message ⇒ String
The message indicating that logs failed to be delivered.
8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 |
# File 'lib/aws-sdk-redshift/types.rb', line 8287 class LoggingStatus < Struct.new( :logging_enabled, :bucket_name, :s3_key_prefix, :last_successful_delivery_time, :last_failure_time, :last_failure_message, :log_destination_type, :log_exports, :s3_tables) SENSITIVE = [] include Aws::Structure end |
#last_failure_time ⇒ Time
The last time when logs failed to be delivered.
8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 |
# File 'lib/aws-sdk-redshift/types.rb', line 8287 class LoggingStatus < Struct.new( :logging_enabled, :bucket_name, :s3_key_prefix, :last_successful_delivery_time, :last_failure_time, :last_failure_message, :log_destination_type, :log_exports, :s3_tables) SENSITIVE = [] include Aws::Structure end |
#last_successful_delivery_time ⇒ Time
The last time that logs were delivered.
8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 |
# File 'lib/aws-sdk-redshift/types.rb', line 8287 class LoggingStatus < Struct.new( :logging_enabled, :bucket_name, :s3_key_prefix, :last_successful_delivery_time, :last_failure_time, :last_failure_message, :log_destination_type, :log_exports, :s3_tables) SENSITIVE = [] include Aws::Structure end |
#log_destination_type ⇒ String
The log destination type. An enum with possible values of s3,
cloudwatch, and s3table.
8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 |
# File 'lib/aws-sdk-redshift/types.rb', line 8287 class LoggingStatus < Struct.new( :logging_enabled, :bucket_name, :s3_key_prefix, :last_successful_delivery_time, :last_failure_time, :last_failure_message, :log_destination_type, :log_exports, :s3_tables) SENSITIVE = [] include Aws::Structure end |
#log_exports ⇒ Array<String>
The collection of exported log types. When LogDestinationType is
s3 or cloudwatch, possible values are connectionlog,
useractivitylog, and userlog. When LogDestinationType is
s3table, the values are the names of the system tables being
published.
8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 |
# File 'lib/aws-sdk-redshift/types.rb', line 8287 class LoggingStatus < Struct.new( :logging_enabled, :bucket_name, :s3_key_prefix, :last_successful_delivery_time, :last_failure_time, :last_failure_message, :log_destination_type, :log_exports, :s3_tables) SENSITIVE = [] include Aws::Structure end |
#logging_enabled ⇒ Boolean
true if logging is on, false if logging is off.
8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 |
# File 'lib/aws-sdk-redshift/types.rb', line 8287 class LoggingStatus < Struct.new( :logging_enabled, :bucket_name, :s3_key_prefix, :last_successful_delivery_time, :last_failure_time, :last_failure_message, :log_destination_type, :log_exports, :s3_tables) SENSITIVE = [] include Aws::Structure end |
#s3_key_prefix ⇒ String
The prefix applied to the log file names.
8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 |
# File 'lib/aws-sdk-redshift/types.rb', line 8287 class LoggingStatus < Struct.new( :logging_enabled, :bucket_name, :s3_key_prefix, :last_successful_delivery_time, :last_failure_time, :last_failure_message, :log_destination_type, :log_exports, :s3_tables) SENSITIVE = [] include Aws::Structure end |
#s3_tables ⇒ Types::S3TablePublishStatus
The status of system table publishing to S3 Tables. This field is populated only when system table publishing is active.
8287 8288 8289 8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 |
# File 'lib/aws-sdk-redshift/types.rb', line 8287 class LoggingStatus < Struct.new( :logging_enabled, :bucket_name, :s3_key_prefix, :last_successful_delivery_time, :last_failure_time, :last_failure_message, :log_destination_type, :log_exports, :s3_tables) SENSITIVE = [] include Aws::Structure end |