Class: Aws::Redshift::Types::MaintenanceTrack
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::MaintenanceTrack
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Defines a maintenance track that determines which Amazon Redshift
version to apply during a maintenance window. If the value for
MaintenanceTrack is current, the cluster is updated to the most
recently certified maintenance release. If the value is trailing,
the cluster is updated to the previously certified maintenance
release.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#database_version ⇒ String
The version number for the cluster release.
-
#maintenance_track_name ⇒ String
The name of the maintenance track.
-
#update_targets ⇒ Array<Types::UpdateTarget>
An array of UpdateTarget objects to update with the maintenance track.
Instance Attribute Details
#database_version ⇒ String
The version number for the cluster release.
8259 8260 8261 8262 8263 8264 8265 |
# File 'lib/aws-sdk-redshift/types.rb', line 8259 class MaintenanceTrack < Struct.new( :maintenance_track_name, :database_version, :update_targets) SENSITIVE = [] include Aws::Structure end |
#maintenance_track_name ⇒ String
The name of the maintenance track. Possible values are current and
trailing.
8259 8260 8261 8262 8263 8264 8265 |
# File 'lib/aws-sdk-redshift/types.rb', line 8259 class MaintenanceTrack < Struct.new( :maintenance_track_name, :database_version, :update_targets) SENSITIVE = [] include Aws::Structure end |
#update_targets ⇒ Array<Types::UpdateTarget>
An array of UpdateTarget objects to update with the maintenance track.
8259 8260 8261 8262 8263 8264 8265 |
# File 'lib/aws-sdk-redshift/types.rb', line 8259 class MaintenanceTrack < Struct.new( :maintenance_track_name, :database_version, :update_targets) SENSITIVE = [] include Aws::Structure end |