Method: Aws::Redshift::Types::ModifyClusterMessage#cluster_type
- Defined in:
- lib/aws-sdk-redshift/types.rb
#cluster_type ⇒ String
The new cluster type.
When you submit your cluster resize request, your existing cluster goes into a read-only mode. After Amazon Redshift provisions a new cluster based on your resize requirements, there will be outage for a period while the old cluster is deleted and your connection is switched to the new cluster. You can use DescribeResize to track the progress of the resize request.
Valid Values: ‘ multi-node | single-node `
8688 8689 8690 8691 8692 8693 8694 8695 8696 8697 8698 8699 8700 8701 8702 8703 8704 8705 8706 8707 8708 8709 8710 8711 8712 8713 8714 8715 8716 8717 8718 8719 8720 8721 |
# File 'lib/aws-sdk-redshift/types.rb', line 8688 class ModifyClusterMessage < Struct.new( :cluster_identifier, :cluster_type, :node_type, :number_of_nodes, :cluster_security_groups, :vpc_security_group_ids, :master_user_password, :cluster_parameter_group_name, :automated_snapshot_retention_period, :manual_snapshot_retention_period, :preferred_maintenance_window, :cluster_version, :allow_version_upgrade, :hsm_client_certificate_identifier, :hsm_configuration_identifier, :new_cluster_identifier, :publicly_accessible, :elastic_ip, :enhanced_vpc_routing, :maintenance_track_name, :encrypted, :kms_key_id, :availability_zone_relocation, :availability_zone, :port, :manage_master_password, :master_password_secret_kms_key_id, :ip_address_type, :multi_az, :extra_compute_for_automatic_optimization) SENSITIVE = [:master_user_password] include Aws::Structure end |