Class: Aws::Redshift::Types::ModifyClusterSnapshotMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#forceBoolean

A Boolean option to override an exception if the retention period has already passed.

Returns:

  • (Boolean)


8899
8900
8901
8902
8903
8904
8905
# File 'lib/aws-sdk-redshift/types.rb', line 8899

class ModifyClusterSnapshotMessage < Struct.new(
  :snapshot_identifier,
  :manual_snapshot_retention_period,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#manual_snapshot_retention_periodInteger

The number of days that a manual snapshot is retained. If the value is -1, the manual snapshot is retained indefinitely.

If the manual snapshot falls outside of the new retention period, you can specify the force option to immediately delete the snapshot.

The value must be either -1 or an integer between 1 and 3,653.

Returns:

  • (Integer)


8899
8900
8901
8902
8903
8904
8905
# File 'lib/aws-sdk-redshift/types.rb', line 8899

class ModifyClusterSnapshotMessage < Struct.new(
  :snapshot_identifier,
  :manual_snapshot_retention_period,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_identifierString

The identifier of the snapshot whose setting you want to modify.

Returns:

  • (String)


8899
8900
8901
8902
8903
8904
8905
# File 'lib/aws-sdk-redshift/types.rb', line 8899

class ModifyClusterSnapshotMessage < Struct.new(
  :snapshot_identifier,
  :manual_snapshot_retention_period,
  :force)
  SENSITIVE = []
  include Aws::Structure
end