Class: Aws::Redshift::Types::ModifyLakehouseConfigurationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::ModifyLakehouseConfigurationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_name ⇒ String
The name of the Glue data catalog that will be associated with the cluster enabled with Amazon Redshift federated permissions.
-
#cluster_identifier ⇒ String
The unique identifier of the cluster whose lakehouse configuration you want to modify.
-
#dry_run ⇒ Boolean
A boolean value that, if
true, validates the request without actually modifying the lakehouse configuration. -
#lakehouse_idc_application_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM Identity Center application used for enabling Amazon Web Services IAM Identity Center trusted identity propagation on a cluster enabled with Amazon Redshift federated permissions.
-
#lakehouse_idc_registration ⇒ String
Modifies the Amazon Web Services IAM Identity Center trusted identity propagation on a cluster enabled with Amazon Redshift federated permissions.
-
#lakehouse_registration ⇒ String
Specifies whether to register or deregister the cluster with Amazon Redshift federated permissions.
Instance Attribute Details
#catalog_name ⇒ String
The name of the Glue data catalog that will be associated with the cluster enabled with Amazon Redshift federated permissions.
Constraints:
-
Must contain at least one lowercase letter.
-
Can only contain lowercase letters (a-z), numbers (0-9), underscores (_), and hyphens (-).
Pattern: ^[a-z0-9_-]*[a-z]+[a-z0-9_-]*$
Example: my-catalog_01
9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 |
# File 'lib/aws-sdk-redshift/types.rb', line 9208 class ModifyLakehouseConfigurationMessage < Struct.new( :cluster_identifier, :lakehouse_registration, :catalog_name, :lakehouse_idc_registration, :lakehouse_idc_application_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#cluster_identifier ⇒ String
The unique identifier of the cluster whose lakehouse configuration you want to modify.
9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 |
# File 'lib/aws-sdk-redshift/types.rb', line 9208 class ModifyLakehouseConfigurationMessage < Struct.new( :cluster_identifier, :lakehouse_registration, :catalog_name, :lakehouse_idc_registration, :lakehouse_idc_application_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
A boolean value that, if true, validates the request without
actually modifying the lakehouse configuration. Use this to check
for errors before making changes.
9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 |
# File 'lib/aws-sdk-redshift/types.rb', line 9208 class ModifyLakehouseConfigurationMessage < Struct.new( :cluster_identifier, :lakehouse_registration, :catalog_name, :lakehouse_idc_registration, :lakehouse_idc_application_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#lakehouse_idc_application_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM Identity Center application used for enabling Amazon Web Services IAM Identity Center trusted identity propagation on a cluster enabled with Amazon Redshift federated permissions.
9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 |
# File 'lib/aws-sdk-redshift/types.rb', line 9208 class ModifyLakehouseConfigurationMessage < Struct.new( :cluster_identifier, :lakehouse_registration, :catalog_name, :lakehouse_idc_registration, :lakehouse_idc_application_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#lakehouse_idc_registration ⇒ String
Modifies the Amazon Web Services IAM Identity Center trusted
identity propagation on a cluster enabled with Amazon Redshift
federated permissions. Valid values are Associate or
Disassociate.
9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 |
# File 'lib/aws-sdk-redshift/types.rb', line 9208 class ModifyLakehouseConfigurationMessage < Struct.new( :cluster_identifier, :lakehouse_registration, :catalog_name, :lakehouse_idc_registration, :lakehouse_idc_application_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |
#lakehouse_registration ⇒ String
Specifies whether to register or deregister the cluster with Amazon
Redshift federated permissions. Valid values are Register or
Deregister.
9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 |
# File 'lib/aws-sdk-redshift/types.rb', line 9208 class ModifyLakehouseConfigurationMessage < Struct.new( :cluster_identifier, :lakehouse_registration, :catalog_name, :lakehouse_idc_registration, :lakehouse_idc_application_arn, :dry_run) SENSITIVE = [] include Aws::Structure end |