Method: Aws::Redshift::Types::PendingModifiedValues#enhanced_vpc_routing
- Defined in:
- lib/aws-sdk-redshift/types.rb
#enhanced_vpc_routing ⇒ Boolean
An option that specifies whether to create the cluster with enhanced VPC routing enabled. To create a cluster that uses enhanced VPC routing, the cluster must be in a VPC. For more information, see
- Enhanced VPC Routing][1
-
in the Amazon Redshift Cluster Management
Guide.
If this option is true, enhanced VPC routing is enabled.
Default: false
[1]: docs.aws.amazon.com/redshift/latest/mgmt/enhanced-vpc-routing.html
9786 9787 9788 9789 9790 9791 9792 9793 9794 9795 9796 9797 9798 9799 9800 |
# File 'lib/aws-sdk-redshift/types.rb', line 9786 class PendingModifiedValues < Struct.new( :master_user_password, :node_type, :number_of_nodes, :cluster_type, :cluster_version, :automated_snapshot_retention_period, :cluster_identifier, :publicly_accessible, :enhanced_vpc_routing, :maintenance_track_name, :encryption_type) SENSITIVE = [:master_user_password] include Aws::Structure end |