Class: Aws::Redshift::Types::ReservedNodeOffering
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::ReservedNodeOffering
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Describes a reserved node offering.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The currency code for the compute nodes offering.
-
#duration ⇒ Integer
The duration, in seconds, for which the offering will reserve the node.
-
#fixed_price ⇒ Float
The upfront fixed charge you will pay to purchase the specific reserved node offering.
-
#node_type ⇒ String
The node type offered by the reserved node offering.
-
#offering_type ⇒ String
The anticipated utilization of the reserved node, as defined in the reserved node offering.
-
#recurring_charges ⇒ Array<Types::RecurringCharge>
The charge to your account regardless of whether you are creating any clusters using the node offering.
-
#reserved_node_offering_id ⇒ String
The offering identifier.
- #reserved_node_offering_type ⇒ String
-
#usage_price ⇒ Float
The rate you are charged for each hour the cluster that is using the offering is running.
Instance Attribute Details
#currency_code ⇒ String
The currency code for the compute nodes offering.
10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 |
# File 'lib/aws-sdk-redshift/types.rb', line 10720 class ReservedNodeOffering < Struct.new( :reserved_node_offering_id, :node_type, :duration, :fixed_price, :usage_price, :currency_code, :offering_type, :recurring_charges, :reserved_node_offering_type) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The duration, in seconds, for which the offering will reserve the node.
10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 |
# File 'lib/aws-sdk-redshift/types.rb', line 10720 class ReservedNodeOffering < Struct.new( :reserved_node_offering_id, :node_type, :duration, :fixed_price, :usage_price, :currency_code, :offering_type, :recurring_charges, :reserved_node_offering_type) SENSITIVE = [] include Aws::Structure end |
#fixed_price ⇒ Float
The upfront fixed charge you will pay to purchase the specific reserved node offering.
10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 |
# File 'lib/aws-sdk-redshift/types.rb', line 10720 class ReservedNodeOffering < Struct.new( :reserved_node_offering_id, :node_type, :duration, :fixed_price, :usage_price, :currency_code, :offering_type, :recurring_charges, :reserved_node_offering_type) SENSITIVE = [] include Aws::Structure end |
#node_type ⇒ String
The node type offered by the reserved node offering.
10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 |
# File 'lib/aws-sdk-redshift/types.rb', line 10720 class ReservedNodeOffering < Struct.new( :reserved_node_offering_id, :node_type, :duration, :fixed_price, :usage_price, :currency_code, :offering_type, :recurring_charges, :reserved_node_offering_type) SENSITIVE = [] include Aws::Structure end |
#offering_type ⇒ String
The anticipated utilization of the reserved node, as defined in the reserved node offering.
10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 |
# File 'lib/aws-sdk-redshift/types.rb', line 10720 class ReservedNodeOffering < Struct.new( :reserved_node_offering_id, :node_type, :duration, :fixed_price, :usage_price, :currency_code, :offering_type, :recurring_charges, :reserved_node_offering_type) SENSITIVE = [] include Aws::Structure end |
#recurring_charges ⇒ Array<Types::RecurringCharge>
The charge to your account regardless of whether you are creating any clusters using the node offering. Recurring charges are only in effect for heavy-utilization reserved nodes.
10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 |
# File 'lib/aws-sdk-redshift/types.rb', line 10720 class ReservedNodeOffering < Struct.new( :reserved_node_offering_id, :node_type, :duration, :fixed_price, :usage_price, :currency_code, :offering_type, :recurring_charges, :reserved_node_offering_type) SENSITIVE = [] include Aws::Structure end |
#reserved_node_offering_id ⇒ String
The offering identifier.
10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 |
# File 'lib/aws-sdk-redshift/types.rb', line 10720 class ReservedNodeOffering < Struct.new( :reserved_node_offering_id, :node_type, :duration, :fixed_price, :usage_price, :currency_code, :offering_type, :recurring_charges, :reserved_node_offering_type) SENSITIVE = [] include Aws::Structure end |
#reserved_node_offering_type ⇒ String
10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 |
# File 'lib/aws-sdk-redshift/types.rb', line 10720 class ReservedNodeOffering < Struct.new( :reserved_node_offering_id, :node_type, :duration, :fixed_price, :usage_price, :currency_code, :offering_type, :recurring_charges, :reserved_node_offering_type) SENSITIVE = [] include Aws::Structure end |
#usage_price ⇒ Float
The rate you are charged for each hour the cluster that is using the offering is running.
10720 10721 10722 10723 10724 10725 10726 10727 10728 10729 10730 10731 10732 |
# File 'lib/aws-sdk-redshift/types.rb', line 10720 class ReservedNodeOffering < Struct.new( :reserved_node_offering_id, :node_type, :duration, :fixed_price, :usage_price, :currency_code, :offering_type, :recurring_charges, :reserved_node_offering_type) SENSITIVE = [] include Aws::Structure end |