Class: Aws::Redshift::Types::ReservedNodeOffering

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Describes a reserved node offering.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#currency_codeString

The currency code for the compute nodes offering.



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
# File 'lib/aws-sdk-redshift/types.rb', line 10077

class ReservedNodeOffering < Struct.new(
  :reserved_node_offering_id,
  :node_type,
  :duration,
  :fixed_price,
  :usage_price,
  :currency_code,
  :offering_type,
  :recurring_charges,
  :reserved_node_offering_type)
  SENSITIVE = []
  include Aws::Structure
end

#durationInteger

The duration, in seconds, for which the offering will reserve the node.



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
# File 'lib/aws-sdk-redshift/types.rb', line 10077

class ReservedNodeOffering < Struct.new(
  :reserved_node_offering_id,
  :node_type,
  :duration,
  :fixed_price,
  :usage_price,
  :currency_code,
  :offering_type,
  :recurring_charges,
  :reserved_node_offering_type)
  SENSITIVE = []
  include Aws::Structure
end

#fixed_priceFloat

The upfront fixed charge you will pay to purchase the specific reserved node offering.



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
# File 'lib/aws-sdk-redshift/types.rb', line 10077

class ReservedNodeOffering < Struct.new(
  :reserved_node_offering_id,
  :node_type,
  :duration,
  :fixed_price,
  :usage_price,
  :currency_code,
  :offering_type,
  :recurring_charges,
  :reserved_node_offering_type)
  SENSITIVE = []
  include Aws::Structure
end

#node_typeString

The node type offered by the reserved node offering.



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
# File 'lib/aws-sdk-redshift/types.rb', line 10077

class ReservedNodeOffering < Struct.new(
  :reserved_node_offering_id,
  :node_type,
  :duration,
  :fixed_price,
  :usage_price,
  :currency_code,
  :offering_type,
  :recurring_charges,
  :reserved_node_offering_type)
  SENSITIVE = []
  include Aws::Structure
end

#offering_typeString

The anticipated utilization of the reserved node, as defined in the reserved node offering.



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
# File 'lib/aws-sdk-redshift/types.rb', line 10077

class ReservedNodeOffering < Struct.new(
  :reserved_node_offering_id,
  :node_type,
  :duration,
  :fixed_price,
  :usage_price,
  :currency_code,
  :offering_type,
  :recurring_charges,
  :reserved_node_offering_type)
  SENSITIVE = []
  include Aws::Structure
end

#recurring_chargesArray<Types::RecurringCharge>

The charge to your account regardless of whether you are creating any clusters using the node offering. Recurring charges are only in effect for heavy-utilization reserved nodes.



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
# File 'lib/aws-sdk-redshift/types.rb', line 10077

class ReservedNodeOffering < Struct.new(
  :reserved_node_offering_id,
  :node_type,
  :duration,
  :fixed_price,
  :usage_price,
  :currency_code,
  :offering_type,
  :recurring_charges,
  :reserved_node_offering_type)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_node_offering_idString

The offering identifier.



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
# File 'lib/aws-sdk-redshift/types.rb', line 10077

class ReservedNodeOffering < Struct.new(
  :reserved_node_offering_id,
  :node_type,
  :duration,
  :fixed_price,
  :usage_price,
  :currency_code,
  :offering_type,
  :recurring_charges,
  :reserved_node_offering_type)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_node_offering_typeString



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
# File 'lib/aws-sdk-redshift/types.rb', line 10077

class ReservedNodeOffering < Struct.new(
  :reserved_node_offering_id,
  :node_type,
  :duration,
  :fixed_price,
  :usage_price,
  :currency_code,
  :offering_type,
  :recurring_charges,
  :reserved_node_offering_type)
  SENSITIVE = []
  include Aws::Structure
end

#usage_priceFloat

The rate you are charged for each hour the cluster that is using the offering is running.



10077
10078
10079
10080
10081
10082
10083
10084
10085
10086
10087
10088
10089
# File 'lib/aws-sdk-redshift/types.rb', line 10077

class ReservedNodeOffering < Struct.new(
  :reserved_node_offering_id,
  :node_type,
  :duration,
  :fixed_price,
  :usage_price,
  :currency_code,
  :offering_type,
  :recurring_charges,
  :reserved_node_offering_type)
  SENSITIVE = []
  include Aws::Structure
end