Class: Aws::Redshift::Types::ReservedNodeOfferingsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


10750
10751
10752
10753
10754
10755
# File 'lib/aws-sdk-redshift/types.rb', line 10750

class ReservedNodeOfferingsMessage < Struct.new(
  :marker,
  :reserved_node_offerings)
  SENSITIVE = []
  include Aws::Structure
end

#reserved_node_offeringsArray<Types::ReservedNodeOffering>

A list of ReservedNodeOffering objects.

Returns:



10750
10751
10752
10753
10754
10755
# File 'lib/aws-sdk-redshift/types.rb', line 10750

class ReservedNodeOfferingsMessage < Struct.new(
  :marker,
  :reserved_node_offerings)
  SENSITIVE = []
  include Aws::Structure
end