Class: Aws::Redshift::Types::ReservedNodeOfferingsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::ReservedNodeOfferingsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#reserved_node_offerings ⇒ Array<Types::ReservedNodeOffering>
A list of
ReservedNodeOfferingobjects.
Instance Attribute Details
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.
10112 10113 10114 10115 10116 10117 |
# File 'lib/aws-sdk-redshift/types.rb', line 10112 class ReservedNodeOfferingsMessage < Struct.new( :marker, :reserved_node_offerings) SENSITIVE = [] include Aws::Structure end |
#reserved_node_offerings ⇒ Array<Types::ReservedNodeOffering>
A list of ReservedNodeOffering objects.
10112 10113 10114 10115 10116 10117 |
# File 'lib/aws-sdk-redshift/types.rb', line 10112 class ReservedNodeOfferingsMessage < Struct.new( :marker, :reserved_node_offerings) SENSITIVE = [] include Aws::Structure end |