Class: Aws::Redshift::Types::ResizeClusterMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::ResizeClusterMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Describes a resize cluster operation. For example, a scheduled action
to run the ResizeCluster API operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#classic ⇒ Boolean
A boolean value indicating whether the resize operation is using the classic resize process.
-
#cluster_identifier ⇒ String
The unique identifier for the cluster to resize.
-
#cluster_type ⇒ String
The new cluster type for the specified cluster.
-
#node_type ⇒ String
The new node type for the nodes you are adding.
-
#number_of_nodes ⇒ Integer
The new number of nodes for the cluster.
-
#reserved_node_id ⇒ String
The identifier of the reserved node.
-
#target_reserved_node_offering_id ⇒ String
The identifier of the target reserved node offering.
Instance Attribute Details
#classic ⇒ Boolean
A boolean value indicating whether the resize operation is using the
classic resize process. If you don't provide this parameter or set
the value to false, the resize type is elastic.
10923 10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 |
# File 'lib/aws-sdk-redshift/types.rb', line 10923 class ResizeClusterMessage < Struct.new( :cluster_identifier, :cluster_type, :node_type, :number_of_nodes, :classic, :reserved_node_id, :target_reserved_node_offering_id) SENSITIVE = [] include Aws::Structure end |
#cluster_identifier ⇒ String
The unique identifier for the cluster to resize.
10923 10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 |
# File 'lib/aws-sdk-redshift/types.rb', line 10923 class ResizeClusterMessage < Struct.new( :cluster_identifier, :cluster_type, :node_type, :number_of_nodes, :classic, :reserved_node_id, :target_reserved_node_offering_id) SENSITIVE = [] include Aws::Structure end |
#cluster_type ⇒ String
The new cluster type for the specified cluster.
10923 10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 |
# File 'lib/aws-sdk-redshift/types.rb', line 10923 class ResizeClusterMessage < Struct.new( :cluster_identifier, :cluster_type, :node_type, :number_of_nodes, :classic, :reserved_node_id, :target_reserved_node_offering_id) SENSITIVE = [] include Aws::Structure end |
#node_type ⇒ String
The new node type for the nodes you are adding. If not specified, the cluster's current node type is used.
10923 10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 |
# File 'lib/aws-sdk-redshift/types.rb', line 10923 class ResizeClusterMessage < Struct.new( :cluster_identifier, :cluster_type, :node_type, :number_of_nodes, :classic, :reserved_node_id, :target_reserved_node_offering_id) SENSITIVE = [] include Aws::Structure end |
#number_of_nodes ⇒ Integer
The new number of nodes for the cluster. If not specified, the cluster's current number of nodes is used.
10923 10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 |
# File 'lib/aws-sdk-redshift/types.rb', line 10923 class ResizeClusterMessage < Struct.new( :cluster_identifier, :cluster_type, :node_type, :number_of_nodes, :classic, :reserved_node_id, :target_reserved_node_offering_id) SENSITIVE = [] include Aws::Structure end |
#reserved_node_id ⇒ String
The identifier of the reserved node.
10923 10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 |
# File 'lib/aws-sdk-redshift/types.rb', line 10923 class ResizeClusterMessage < Struct.new( :cluster_identifier, :cluster_type, :node_type, :number_of_nodes, :classic, :reserved_node_id, :target_reserved_node_offering_id) SENSITIVE = [] include Aws::Structure end |
#target_reserved_node_offering_id ⇒ String
The identifier of the target reserved node offering.
10923 10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 |
# File 'lib/aws-sdk-redshift/types.rb', line 10923 class ResizeClusterMessage < Struct.new( :cluster_identifier, :cluster_type, :node_type, :number_of_nodes, :classic, :reserved_node_id, :target_reserved_node_offering_id) SENSITIVE = [] include Aws::Structure end |