Class: Aws::Redshift::Types::RestoreTableFromClusterSnapshotMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::RestoreTableFromClusterSnapshotMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_identifier ⇒ String
The identifier of the Amazon Redshift cluster to restore the table to.
-
#enable_case_sensitive_identifier ⇒ Boolean
Indicates whether name identifiers for database, schema, and table are case sensitive.
-
#new_table_name ⇒ String
The name of the table to create as a result of the current request.
-
#snapshot_identifier ⇒ String
The identifier of the snapshot to restore the table from.
-
#source_database_name ⇒ String
The name of the source database that contains the table to restore from.
-
#source_schema_name ⇒ String
The name of the source schema that contains the table to restore from.
-
#source_table_name ⇒ String
The name of the source table to restore from.
-
#target_database_name ⇒ String
The name of the database to restore the table to.
-
#target_schema_name ⇒ String
The name of the schema to restore the table to.
Instance Attribute Details
#cluster_identifier ⇒ String
The identifier of the Amazon Redshift cluster to restore the table to.
10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 |
# File 'lib/aws-sdk-redshift/types.rb', line 10881 class RestoreTableFromClusterSnapshotMessage < Struct.new( :cluster_identifier, :snapshot_identifier, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :new_table_name, :enable_case_sensitive_identifier) SENSITIVE = [] include Aws::Structure end |
#enable_case_sensitive_identifier ⇒ Boolean
Indicates whether name identifiers for database, schema, and table are case sensitive. If true, the names are case sensitive. If false (default), the names are not case sensitive.
10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 |
# File 'lib/aws-sdk-redshift/types.rb', line 10881 class RestoreTableFromClusterSnapshotMessage < Struct.new( :cluster_identifier, :snapshot_identifier, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :new_table_name, :enable_case_sensitive_identifier) SENSITIVE = [] include Aws::Structure end |
#new_table_name ⇒ String
The name of the table to create as a result of the current request.
10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 |
# File 'lib/aws-sdk-redshift/types.rb', line 10881 class RestoreTableFromClusterSnapshotMessage < Struct.new( :cluster_identifier, :snapshot_identifier, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :new_table_name, :enable_case_sensitive_identifier) SENSITIVE = [] include Aws::Structure end |
#snapshot_identifier ⇒ String
The identifier of the snapshot to restore the table from. This snapshot must have been created from the Amazon Redshift cluster specified by the ClusterIdentifier parameter.
10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 |
# File 'lib/aws-sdk-redshift/types.rb', line 10881 class RestoreTableFromClusterSnapshotMessage < Struct.new( :cluster_identifier, :snapshot_identifier, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :new_table_name, :enable_case_sensitive_identifier) SENSITIVE = [] include Aws::Structure end |
#source_database_name ⇒ String
The name of the source database that contains the table to restore from.
10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 |
# File 'lib/aws-sdk-redshift/types.rb', line 10881 class RestoreTableFromClusterSnapshotMessage < Struct.new( :cluster_identifier, :snapshot_identifier, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :new_table_name, :enable_case_sensitive_identifier) SENSITIVE = [] include Aws::Structure end |
#source_schema_name ⇒ String
The name of the source schema that contains the table to restore from. If you do not specify a SourceSchemaName value, the default is public.
10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 |
# File 'lib/aws-sdk-redshift/types.rb', line 10881 class RestoreTableFromClusterSnapshotMessage < Struct.new( :cluster_identifier, :snapshot_identifier, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :new_table_name, :enable_case_sensitive_identifier) SENSITIVE = [] include Aws::Structure end |
#source_table_name ⇒ String
The name of the source table to restore from.
10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 |
# File 'lib/aws-sdk-redshift/types.rb', line 10881 class RestoreTableFromClusterSnapshotMessage < Struct.new( :cluster_identifier, :snapshot_identifier, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :new_table_name, :enable_case_sensitive_identifier) SENSITIVE = [] include Aws::Structure end |
#target_database_name ⇒ String
The name of the database to restore the table to.
10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 |
# File 'lib/aws-sdk-redshift/types.rb', line 10881 class RestoreTableFromClusterSnapshotMessage < Struct.new( :cluster_identifier, :snapshot_identifier, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :new_table_name, :enable_case_sensitive_identifier) SENSITIVE = [] include Aws::Structure end |
#target_schema_name ⇒ String
The name of the schema to restore the table to.
10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 |
# File 'lib/aws-sdk-redshift/types.rb', line 10881 class RestoreTableFromClusterSnapshotMessage < Struct.new( :cluster_identifier, :snapshot_identifier, :source_database_name, :source_schema_name, :source_table_name, :target_database_name, :target_schema_name, :new_table_name, :enable_case_sensitive_identifier) SENSITIVE = [] include Aws::Structure end |