Class: Aws::Redshift::Types::RestoreTableFromClusterSnapshotMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshift/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

The identifier of the Amazon Redshift cluster to restore the table to.



10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
# File 'lib/aws-sdk-redshift/types.rb', line 10591

class RestoreTableFromClusterSnapshotMessage < Struct.new(
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name,
  :enable_case_sensitive_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#enable_case_sensitive_identifierBoolean

Indicates whether name identifiers for database, schema, and table are case sensitive. If true, the names are case sensitive. If false (default), the names are not case sensitive.



10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
# File 'lib/aws-sdk-redshift/types.rb', line 10591

class RestoreTableFromClusterSnapshotMessage < Struct.new(
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name,
  :enable_case_sensitive_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#new_table_nameString

The name of the table to create as a result of the current request.



10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
# File 'lib/aws-sdk-redshift/types.rb', line 10591

class RestoreTableFromClusterSnapshotMessage < Struct.new(
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name,
  :enable_case_sensitive_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_identifierString

The identifier of the snapshot to restore the table from. This snapshot must have been created from the Amazon Redshift cluster specified by the ClusterIdentifier parameter.



10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
# File 'lib/aws-sdk-redshift/types.rb', line 10591

class RestoreTableFromClusterSnapshotMessage < Struct.new(
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name,
  :enable_case_sensitive_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#source_database_nameString

The name of the source database that contains the table to restore from.



10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
# File 'lib/aws-sdk-redshift/types.rb', line 10591

class RestoreTableFromClusterSnapshotMessage < Struct.new(
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name,
  :enable_case_sensitive_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#source_schema_nameString

The name of the source schema that contains the table to restore from. If you do not specify a SourceSchemaName value, the default is public.



10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
# File 'lib/aws-sdk-redshift/types.rb', line 10591

class RestoreTableFromClusterSnapshotMessage < Struct.new(
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name,
  :enable_case_sensitive_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#source_table_nameString

The name of the source table to restore from.



10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
# File 'lib/aws-sdk-redshift/types.rb', line 10591

class RestoreTableFromClusterSnapshotMessage < Struct.new(
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name,
  :enable_case_sensitive_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#target_database_nameString

The name of the database to restore the table to.



10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
# File 'lib/aws-sdk-redshift/types.rb', line 10591

class RestoreTableFromClusterSnapshotMessage < Struct.new(
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name,
  :enable_case_sensitive_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#target_schema_nameString

The name of the schema to restore the table to.



10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
# File 'lib/aws-sdk-redshift/types.rb', line 10591

class RestoreTableFromClusterSnapshotMessage < Struct.new(
  :cluster_identifier,
  :snapshot_identifier,
  :source_database_name,
  :source_schema_name,
  :source_table_name,
  :target_database_name,
  :target_schema_name,
  :new_table_name,
  :enable_case_sensitive_identifier)
  SENSITIVE = []
  include Aws::Structure
end