Class: Aws::Redshift::Types::ScheduledActionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::ScheduledActionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records.
-
#scheduled_actions ⇒ Array<Types::ScheduledAction>
List of retrieved scheduled actions.
Instance Attribute Details
#marker ⇒ String
An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeScheduledActions request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request.
11337 11338 11339 11340 11341 11342 |
# File 'lib/aws-sdk-redshift/types.rb', line 11337 class ScheduledActionsMessage < Struct.new( :marker, :scheduled_actions) SENSITIVE = [] include Aws::Structure end |
#scheduled_actions ⇒ Array<Types::ScheduledAction>
List of retrieved scheduled actions.
11337 11338 11339 11340 11341 11342 |
# File 'lib/aws-sdk-redshift/types.rb', line 11337 class ScheduledActionsMessage < Struct.new( :marker, :scheduled_actions) SENSITIVE = [] include Aws::Structure end |