Class: Aws::Redshift::Types::Snapshot
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::Snapshot
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Describes a snapshot.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accounts_with_restore_access ⇒ Array<Types::AccountWithRestoreAccess>
A list of the Amazon Web Services accounts authorized to restore the snapshot.
-
#actual_incremental_backup_size_in_mega_bytes ⇒ Float
The size of the incremental backup.
-
#availability_zone ⇒ String
The Availability Zone in which the cluster was created.
-
#backup_progress_in_mega_bytes ⇒ Float
The number of megabytes that have been transferred to the snapshot backup.
-
#cluster_create_time ⇒ Time
The time (UTC) when the cluster was originally created.
-
#cluster_identifier ⇒ String
The identifier of the cluster for which the snapshot was taken.
-
#cluster_version ⇒ String
The version ID of the Amazon Redshift engine that is running on the cluster.
-
#current_backup_rate_in_mega_bytes_per_second ⇒ Float
The number of megabytes per second being transferred to the snapshot backup.
-
#db_name ⇒ String
The name of the database that was created when the cluster was created.
-
#elapsed_time_in_seconds ⇒ Integer
The amount of time an in-progress snapshot backup has been running, or the amount of time it took a completed backup to finish.
-
#encrypted ⇒ Boolean
If
true, the data in the snapshot is encrypted at rest. -
#encrypted_with_hsm ⇒ Boolean
A boolean that indicates whether the snapshot data is encrypted using the HSM keys of the source cluster.
-
#engine_full_version ⇒ String
The cluster version of the cluster used to create the snapshot.
-
#enhanced_vpc_routing ⇒ Boolean
An option that specifies whether to create the cluster with enhanced VPC routing enabled.
-
#estimated_seconds_to_completion ⇒ Integer
The estimate of the time remaining before the snapshot backup will complete.
-
#kms_key_id ⇒ String
The Key Management Service (KMS) key ID of the encryption key that was used to encrypt data in the cluster from which the snapshot was taken.
-
#maintenance_track_name ⇒ String
The name of the maintenance track for the snapshot.
-
#manual_snapshot_remaining_days ⇒ Integer
The number of days until a manual snapshot will pass its retention period.
-
#manual_snapshot_retention_period ⇒ Integer
The number of days that a manual snapshot is retained.
-
#master_password_secret_arn ⇒ String
The Amazon Resource Name (ARN) for the cluster's admin user credentials secret.
-
#master_password_secret_kms_key_id ⇒ String
The ID of the Key Management Service (KMS) key used to encrypt and store the cluster's admin credentials secret.
-
#master_username ⇒ String
The admin user name for the cluster.
-
#node_type ⇒ String
The node type of the nodes in the cluster.
-
#number_of_nodes ⇒ Integer
The number of nodes in the cluster.
-
#owner_account ⇒ String
For manual snapshots, the Amazon Web Services account used to create or copy the snapshot.
-
#port ⇒ Integer
The port that the cluster is listening on.
-
#restorable_node_types ⇒ Array<String>
The list of node types that this cluster snapshot is able to restore into.
-
#snapshot_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot.
-
#snapshot_create_time ⇒ Time
The time (in UTC format) when Amazon Redshift began the snapshot.
-
#snapshot_identifier ⇒ String
The snapshot identifier that is provided in the request.
-
#snapshot_retention_start_time ⇒ Time
A timestamp representing the start of the retention period for the snapshot.
-
#snapshot_type ⇒ String
The snapshot type.
-
#source_region ⇒ String
The source region from which the snapshot was copied.
-
#status ⇒ String
The snapshot status.
-
#tags ⇒ Array<Types::Tag>
The list of tags for the cluster snapshot.
-
#total_backup_size_in_mega_bytes ⇒ Float
The size of the complete set of backup data that would be used to restore the cluster.
-
#vpc_id ⇒ String
The VPC identifier of the cluster if the snapshot is from a cluster in a VPC.
Instance Attribute Details
#accounts_with_restore_access ⇒ Array<Types::AccountWithRestoreAccess>
A list of the Amazon Web Services accounts authorized to restore the
snapshot. Returns null if no accounts are authorized. Visible only
to the snapshot owner.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#actual_incremental_backup_size_in_mega_bytes ⇒ Float
The size of the incremental backup.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Availability Zone in which the cluster was created.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#backup_progress_in_mega_bytes ⇒ Float
The number of megabytes that have been transferred to the snapshot backup.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#cluster_create_time ⇒ Time
The time (UTC) when the cluster was originally created.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#cluster_identifier ⇒ String
The identifier of the cluster for which the snapshot was taken.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#cluster_version ⇒ String
The version ID of the Amazon Redshift engine that is running on the cluster.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#current_backup_rate_in_mega_bytes_per_second ⇒ Float
The number of megabytes per second being transferred to the snapshot
backup. Returns 0 for a completed backup.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#db_name ⇒ String
The name of the database that was created when the cluster was created.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#elapsed_time_in_seconds ⇒ Integer
The amount of time an in-progress snapshot backup has been running, or the amount of time it took a completed backup to finish.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
If true, the data in the snapshot is encrypted at rest.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#encrypted_with_hsm ⇒ Boolean
A boolean that indicates whether the snapshot data is encrypted
using the HSM keys of the source cluster. true indicates that the
data is encrypted using HSM keys.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#engine_full_version ⇒ String
The cluster version of the cluster used to create the snapshot. For example, 1.0.15503.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#enhanced_vpc_routing ⇒ Boolean
An option that specifies whether to create the cluster with enhanced VPC routing enabled. To create a cluster that uses enhanced VPC routing, the cluster must be in a VPC. For more information, see Enhanced VPC Routing in the Amazon Redshift Cluster Management Guide.
If this option is true, enhanced VPC routing is enabled.
Default: false
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#estimated_seconds_to_completion ⇒ Integer
The estimate of the time remaining before the snapshot backup will
complete. Returns 0 for a completed backup.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Key Management Service (KMS) key ID of the encryption key that was used to encrypt data in the cluster from which the snapshot was taken.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#maintenance_track_name ⇒ String
The name of the maintenance track for the snapshot.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#manual_snapshot_remaining_days ⇒ Integer
The number of days until a manual snapshot will pass its retention period.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#manual_snapshot_retention_period ⇒ Integer
The number of days that a manual snapshot is retained. If the value is -1, the manual snapshot is retained indefinitely.
The value must be either -1 or an integer between 1 and 3,653.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#master_password_secret_arn ⇒ String
The Amazon Resource Name (ARN) for the cluster's admin user credentials secret.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#master_password_secret_kms_key_id ⇒ String
The ID of the Key Management Service (KMS) key used to encrypt and store the cluster's admin credentials secret.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#master_username ⇒ String
The admin user name for the cluster.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#node_type ⇒ String
The node type of the nodes in the cluster.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#number_of_nodes ⇒ Integer
The number of nodes in the cluster.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#owner_account ⇒ String
For manual snapshots, the Amazon Web Services account used to create or copy the snapshot. For automatic snapshots, the owner of the cluster. The owner can perform all snapshot actions, such as sharing a manual snapshot.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port that the cluster is listening on.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#restorable_node_types ⇒ Array<String>
The list of node types that this cluster snapshot is able to restore into.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#snapshot_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#snapshot_create_time ⇒ Time
The time (in UTC format) when Amazon Redshift began the snapshot. A snapshot contains a copy of the cluster data as of this exact time.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#snapshot_identifier ⇒ String
The snapshot identifier that is provided in the request.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_start_time ⇒ Time
A timestamp representing the start of the retention period for the snapshot.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#snapshot_type ⇒ String
The snapshot type. Snapshots created using CreateClusterSnapshot and CopyClusterSnapshot are of type "manual".
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#source_region ⇒ String
The source region from which the snapshot was copied.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The snapshot status. The value of the status depends on the API operation used:
-
CreateClusterSnapshot and CopyClusterSnapshot returns status as "creating".
-
DescribeClusterSnapshots returns status as "creating", "available", "final snapshot", or "failed".
-
DeleteClusterSnapshot returns status as "deleted".
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The list of tags for the cluster snapshot.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#total_backup_size_in_mega_bytes ⇒ Float
The size of the complete set of backup data that would be used to restore the cluster.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The VPC identifier of the cluster if the snapshot is from a cluster in a VPC. Otherwise, this field is not in the output.
12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 |
# File 'lib/aws-sdk-redshift/types.rb', line 12286 class Snapshot < Struct.new( :snapshot_identifier, :cluster_identifier, :snapshot_create_time, :status, :port, :availability_zone, :cluster_create_time, :master_username, :cluster_version, :engine_full_version, :snapshot_type, :node_type, :number_of_nodes, :db_name, :vpc_id, :encrypted, :kms_key_id, :encrypted_with_hsm, :accounts_with_restore_access, :owner_account, :total_backup_size_in_mega_bytes, :actual_incremental_backup_size_in_mega_bytes, :backup_progress_in_mega_bytes, :current_backup_rate_in_mega_bytes_per_second, :estimated_seconds_to_completion, :elapsed_time_in_seconds, :source_region, :tags, :restorable_node_types, :enhanced_vpc_routing, :maintenance_track_name, :manual_snapshot_retention_period, :manual_snapshot_remaining_days, :snapshot_retention_start_time, :master_password_secret_arn, :master_password_secret_kms_key_id, :snapshot_arn) SENSITIVE = [] include Aws::Structure end |