Class: Aws::Redshift::Types::SnapshotMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::SnapshotMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Contains the output from the DescribeClusterSnapshots action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#snapshots ⇒ Array<Types::Snapshot>
A list of Snapshot instances.
Instance Attribute Details
#marker ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned marker value in the Marker parameter and retrying the command. If the Marker field is empty, all response records have been retrieved for the request.
11785 11786 11787 11788 11789 11790 |
# File 'lib/aws-sdk-redshift/types.rb', line 11785 class SnapshotMessage < Struct.new( :marker, :snapshots) SENSITIVE = [] include Aws::Structure end |
#snapshots ⇒ Array<Types::Snapshot>
A list of Snapshot instances.
11785 11786 11787 11788 11789 11790 |
# File 'lib/aws-sdk-redshift/types.rb', line 11785 class SnapshotMessage < Struct.new( :marker, :snapshots) SENSITIVE = [] include Aws::Structure end |