Class: Aws::Redshift::Types::TrackListMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::Redshift::Types::TrackListMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshift/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#maintenance_tracks ⇒ Array<Types::MaintenanceTrack>
A list of maintenance tracks output by the
DescribeClusterTracksoperation. -
#marker ⇒ String
The starting point to return a set of response tracklist records.
Instance Attribute Details
#maintenance_tracks ⇒ Array<Types::MaintenanceTrack>
A list of maintenance tracks output by the DescribeClusterTracks
operation.
13014 13015 13016 13017 13018 13019 |
# File 'lib/aws-sdk-redshift/types.rb', line 13014 class TrackListMessage < Struct.new( :maintenance_tracks, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
The starting point to return a set of response tracklist records.
You can retrieve the next set of response records by providing the
returned marker value in the Marker parameter and retrying the
request.
13014 13015 13016 13017 13018 13019 |
# File 'lib/aws-sdk-redshift/types.rb', line 13014 class TrackListMessage < Struct.new( :maintenance_tracks, :marker) SENSITIVE = [] include Aws::Structure end |